@@ -68,7 +68,7 @@ rm -rf images
 mkdir images
 cp html/images/* images
 make epub
-make -e chunked-html 2>&1 | tee -a doc-errors.log
+make -e chunked-html-web 2>&1 | tee -a doc-errors.log
 
 if [[ "$reference" == *"trunk"* ]]; then  #only do this for trunk because only trunk follows transifex
   #make update-po
