@@ -91,21 +91,6 @@ static void AddStdHashEntry(MemoryContext mcxt, STANDARDIZER *std);
 static StdHashEntry *GetStdHashEntry(MemoryContext mcxt);
 static void DeleteStdHashEntry(MemoryContext mcxt);
 
-/* Memory context cache function prototypes */
-static void StdCacheInit(MemoryContext context);
-static void StdCacheReset(MemoryContext context);
-static void StdCacheDelete(MemoryContext context);
-static bool StdCacheIsEmpty(MemoryContext context);
-
-#if POSTGIS_PGSQL_VERSION >= 96
-static void StdCacheStats(MemoryContext context, int level, bool print, MemoryContextCounters *totals);
-#else
-static void StdCacheStats(MemoryContext context, int level);
-#endif
-
-#ifdef MEMORY_CONTEXT_CHECKING
-static void StdCacheCheck(MemoryContext context);
-#endif
 
 static bool IsInStdPortalCache(StdPortalCache *STDCache,  char *lextab, char *gaztab, char *rultab);
 static STANDARDIZER *GetStdFromPortalCache(StdPortalCache *STDCache,  char *lextab, char *gaztab, char *rultab);
@@ -124,41 +109,19 @@ static int fetch_rules_columns(SPITupleTable *tuptable, rules_columns_t *rules_c
 static int load_rules(RULES *rules, char *tabname);
 
 
-/* Memory context definition must match the current version of PostgreSQL */
-static MemoryContextMethods StdCacheContextMethods =
-{
-    NULL,
-    NULL,
-    NULL,
-    StdCacheInit,
-    StdCacheReset,
-    StdCacheDelete,
-    NULL,
-    StdCacheIsEmpty,
-    StdCacheStats
-#ifdef MEMORY_CONTEXT_CHECKING
-    , StdCacheCheck
-#endif
-};
+
 
 
 static void
-StdCacheInit(MemoryContext context)
-{
-    /* NOP - initialized when first used. */
-}
+#if POSTGIS_PGSQL_VERSION < 96
 
-
-static void
-StdCacheReset(MemoryContext context)
-{
-    // NOP - Seems to be a required function
-}
-
-
-static void
 StdCacheDelete(MemoryContext context)
 {
+#else
+StdCacheDelete(void *ptr)
+{
+	MemoryContext context = (MemoryContext)ptr;
+#endif
     StdHashEntry *she;
 
     DBG("Enter: StdCacheDelete");
@@ -177,6 +140,20 @@ StdCacheDelete(MemoryContext context)
     DeleteStdHashEntry(context);
 }
 
+#if POSTGIS_PGSQL_VERSION < 96
+
+static void
+StdCacheInit(MemoryContext context)
+{
+    /* NOP - initialized when first used. */
+}
+
+
+static void
+StdCacheReset(MemoryContext context)
+{
+    // NOP - Seems to be a required function
+}
 
 static bool
 StdCacheIsEmpty(MemoryContext context)
@@ -185,23 +162,12 @@ StdCacheIsEmpty(MemoryContext context)
     return FALSE;
 }
 
-
-#if POSTGIS_PGSQL_VERSION >= 96
-static void
-StdCacheStats(MemoryContext context, int level, bool print, MemoryContextCounters *totals)
-{
-    // another required function
-    fprintf(stderr, "%s: STANDARDIZER context\n", context->name);
-}
-#else
 static void
 StdCacheStats(MemoryContext context, int level)
 {
     // another required function
     fprintf(stderr, "%s: STANDARDIZER context\n", context->name);
 }
-#endif
-
 
 #ifdef MEMORY_CONTEXT_CHECKING
 static void
@@ -211,6 +177,25 @@ StdCacheCheck(MemoryContext context)
 }
 #endif
 
+/* Memory context definition must match the current version of PostgreSQL */
+static MemoryContextMethods StdCacheContextMethods =
+{
+    NULL,
+    NULL,
+    NULL,
+    StdCacheInit,
+    StdCacheReset,
+    StdCacheDelete,
+    NULL,
+    StdCacheIsEmpty,
+    StdCacheStats
+#ifdef MEMORY_CONTEXT_CHECKING
+    , StdCacheCheck
+#endif
+};
+
+#endif /* POSTGIS_PGSQL_VERSION < 96 */
+
 
 uint32
 mcxt_ptr_hash_std(const void *key, Size keysize)
@@ -379,6 +364,9 @@ AddToStdPortalCache(StdPortalCache *STDCache, char *lextab, char *gaztab, char *
     MemoryContext STDMemoryContext;
     MemoryContext old_context;
     STANDARDIZER *std = NULL;
+#if POSTGIS_PGSQL_VERSION >= 96
+		MemoryContextCallback *callback;
+#endif
 
     DBG("Enter: AddToStdPortalCache");
     std = CreateStd(lextab, gaztab, rultab);
@@ -397,10 +385,27 @@ AddToStdPortalCache(StdPortalCache *STDCache, char *lextab, char *gaztab, char *
 
     DBG("Adding item to STD cache ('%s', '%s', '%s') index %d", lextab, gaztab, rultab, STDCache->NextSlot);
 
+
+#if POSTGIS_PGSQL_VERSION < 96
     STDMemoryContext = MemoryContextCreate(T_AllocSetContext, 8192,
                                            &StdCacheContextMethods,
                                            STDCache->StdCacheContext,
                                            "PAGC STD Memory Context");
+#else
+	STDMemoryContext =  AllocSetContextCreate(STDCache->StdCacheContext,
+	                                          "PAGC STD Memory Context",
+	                                          ALLOCSET_SMALL_SIZES);
+
+	/* PgSQL comments suggest allocating callback in the context */
+	/* being managed, so that the callback object gets cleaned along with */
+	/* the context */
+	callback = MemoryContextAlloc(STDMemoryContext, sizeof(MemoryContextCallback));
+	callback->arg = (void*)(STDMemoryContext);
+	callback->func = StdCacheDelete;
+	MemoryContextRegisterResetCallback(STDMemoryContext, callback);
+#endif
+
+
 
     /* Create the backend hash if it doesn't already exist */
     DBG("Check if StdHash exists (%p)", StdHash);
@@ -685,7 +690,7 @@ static int load_lex(LEXICON *lex, char *tab)
     int ntuples;
     int total_tuples = 0;
 
-    lex_columns_t lex_columns = {seq: -1, word: -1, stdword: -1, token: -1};
+    lex_columns_t lex_columns = {.seq = -1, .word = -1, .stdword = -1, .token = -1};
 
     int seq;
     char *word;
@@ -811,7 +816,7 @@ static int load_rules(RULES *rules, char *tab)
     int ntuples;
     int total_tuples = 0;
 
-    rules_columns_t rules_columns = {rule: -1};
+    rules_columns_t rules_columns = {.rule = -1};
 
     char *rule;
 
