@@ -3,6 +3,7 @@
  * PostGIS - Spatial Types for PostgreSQL
  * http://postgis.net
  * Copyright 2008 Paul Ramsey
+ * Copyright 2018 Darafei Praliaskouski, me@komzpa.net
  *
  * This is free software; you can redistribute and/or modify it under
  * the terms of the GNU General Public Licence. See the COPYING file.
@@ -464,6 +465,84 @@ static void test_point_interpolate(void)
 
 }
 
+static void test_lwline_interpolate_points(void)
+{
+	LWLINE* line = lwgeom_as_lwline(lwgeom_from_wkt("LINESTRING ZM (0 0 3 1, 1 1 2 2, 10 10 4 3)", LW_PARSER_CHECK_NONE));
+	LWLINE* line2d = lwgeom_as_lwline(lwgeom_from_wkt("LINESTRING (1 1, 3 7, 9 12)", LW_PARSER_CHECK_NONE));
+	LWLINE* empty_line = lwgeom_as_lwline(lwgeom_from_wkt("LINESTRING EMPTY", LW_PARSER_CHECK_NONE));
+
+	POINTARRAY* rpa;
+	POINT4D pta;
+	POINT4D ptb;
+	double eps = 1e-10;
+
+	/* Empty line gives empty point */
+	rpa = lwline_interpolate_points(empty_line, 0.5, LW_TRUE);
+	ASSERT_INT_EQUAL(rpa->npoints, 0);
+	ptarray_free(rpa);
+
+	/* Get first endpoint when fraction = 0 */
+	rpa = lwline_interpolate_points(line, 0, LW_TRUE);
+	ASSERT_INT_EQUAL(rpa->npoints, 1);
+	pta = getPoint4d(line->points, 0);
+	ptb = getPoint4d(rpa, 0);
+	ASSERT_POINT4D_EQUAL(pta, ptb, eps);
+	ptarray_free(rpa);
+
+	/* Get last endpoint when fraction = 0 */
+	rpa = lwline_interpolate_points(line, 1, LW_TRUE);
+	ASSERT_INT_EQUAL(rpa->npoints, 1);
+	pta = getPoint4d(line->points, line->points->npoints - 1);
+	ptb = getPoint4d(rpa, 0);
+	ASSERT_POINT4D_EQUAL(pta, ptb, eps);
+	ptarray_free(rpa);
+
+    /* Interpolate a single point */
+    /* First vertex is at 10% */
+	rpa = lwline_interpolate_points(line, 0.1, LW_FALSE);
+	ASSERT_INT_EQUAL(rpa->npoints, 1);
+	pta = getPoint4d(line->points, 1);
+	ptb = getPoint4d(rpa, 0);
+	ASSERT_POINT4D_EQUAL(pta, ptb, eps);
+	ptarray_free(rpa);
+
+	/* 5% is halfway to first vertex */
+	rpa = lwline_interpolate_points(line, 0.05, LW_FALSE);
+	ASSERT_INT_EQUAL(rpa->npoints, 1);
+	pta.x = 0.5;
+	pta.y = 0.5;
+	pta.m = 1.5;
+	pta.z = 2.5;
+	ptb = getPoint4d(rpa, 0);
+	ASSERT_POINT4D_EQUAL(pta, ptb, eps);
+	ptarray_free(rpa);
+
+    /* Now repeat points */
+	rpa = lwline_interpolate_points(line, 0.4, LW_TRUE);
+	ASSERT_INT_EQUAL(rpa->npoints, 2);
+	pta.x = 4;
+	pta.y = 4;
+	ptb = getPoint4d(rpa, 0);
+	ASSERT_POINT2D_EQUAL(pta, ptb, eps);
+
+	pta.x = 8;
+	pta.y = 8;
+	ptb = getPoint4d(rpa, 1);
+	ASSERT_POINT2D_EQUAL(pta, ptb, eps);
+	ptarray_free(rpa);
+
+	/* Make sure it works on 2D lines */
+	rpa = lwline_interpolate_points(line2d, 0.4, LW_TRUE);
+	ASSERT_INT_EQUAL(rpa->npoints, 2);
+	CU_ASSERT_FALSE(ptarray_has_z(rpa));
+	CU_ASSERT_FALSE(ptarray_has_m(rpa));
+	ptarray_free(rpa);
+
+	lwgeom_free(lwline_as_lwgeom(line));
+	lwgeom_free(lwline_as_lwgeom(line2d));
+	lwgeom_free(lwline_as_lwgeom(empty_line));
+}
+
 static void test_lwline_clip(void)
 {
 	LWCOLLECTION *c;
@@ -925,61 +1004,95 @@ static void test_geohash_point_as_int(void)
 	CU_ASSERT_EQUAL(gh, rs);
 }
 
+static void test_lwgeom_remove_repeated_points(void)
+{
+	LWGEOM *g;
+	char *ewkt;
+
+	g = lwgeom_from_wkt("MULTIPOINT(0 0, 10 0, 10 10, 10 10, 0 10, 0 10, 0 10, 0 0, 0 0, 0 0, 5 5, 0 0, 5 5)", LW_PARSER_CHECK_NONE);
+	lwgeom_remove_repeated_points_in_place(g, 1);
+	ewkt = lwgeom_to_ewkt(g);
+	CU_ASSERT_STRING_EQUAL(ewkt, "MULTIPOINT(0 0,10 0,10 10,0 10,5 5)");
+	lwgeom_free(g);
+	lwfree(ewkt);
+
+	g = lwgeom_from_wkt("LINESTRING(1612830.15445 4841287.12672,1612830.15824 4841287.12674,1612829.98813 4841274.56198)", LW_PARSER_CHECK_NONE);
+	lwgeom_remove_repeated_points_in_place(g, 0.01);
+	ewkt = lwgeom_to_ewkt(g);
+	CU_ASSERT_STRING_EQUAL(ewkt, "LINESTRING(1612830.15445 4841287.12672,1612829.98813 4841274.56198)");
+	lwgeom_free(g);
+	lwfree(ewkt);
+
+	g = lwgeom_from_wkt("MULTIPOINT(0 0,10 0,10 10,10 10,0 10,0 10,0 10,0 0,0 0,0 0,5 5,5 5,5 8,8 8,8 8,8 8,8 5,8 5,5 5,5 5,5 5,5 5,5 5,50 50,50 50,50 50,50 60,50 60,50 60,60 60,60 50,60 50,50 50,55 55,55 58,58 58,58 55,58 55,55 55)", LW_PARSER_CHECK_NONE);
+	lwgeom_remove_repeated_points_in_place(g, 1);
+	ewkt = lwgeom_to_ewkt(g);
+	CU_ASSERT_STRING_EQUAL(ewkt, "MULTIPOINT(0 0,10 0,10 10,0 10,5 5,5 8,8 8,8 5,50 50,50 60,60 60,60 50,55 55,55 58,58 58,58 55)");
+	lwgeom_free(g);
+	lwfree(ewkt);
+
+	g = lwgeom_from_wkt("POLYGON((0 0, 0 1, 1 1, 1 0, 0 0))", LW_PARSER_CHECK_NONE);
+	lwgeom_remove_repeated_points_in_place(g, 10000);
+	ewkt = lwgeom_to_ewkt(g);
+	CU_ASSERT_STRING_EQUAL(ewkt, "POLYGON((0 0,1 1,1 0,0 0))");
+	lwgeom_free(g);
+	lwfree(ewkt);
+}
+
 static void test_lwgeom_simplify(void)
 {
-		LWGEOM *l;
-		LWGEOM *g;
-		char *ewkt;
+	LWGEOM *l;
+	LWGEOM *g;
+	char *ewkt;
 
-		/* Simplify but only so far... */
-		g = lwgeom_from_wkt("LINESTRING(0 0, 1 0, 1 1, 0 1, 0 0)", LW_PARSER_CHECK_NONE);
-		l = lwgeom_simplify(g, 10, LW_TRUE);
-		ewkt = lwgeom_to_ewkt(l);
-		CU_ASSERT_STRING_EQUAL(ewkt, "LINESTRING(0 0,0 0)");
-		lwgeom_free(g);
-		lwgeom_free(l);
-		lwfree(ewkt);
+	/* Simplify but only so far... */
+	g = lwgeom_from_wkt("LINESTRING(0 0, 1 0, 1 1, 0 1, 0 0)", LW_PARSER_CHECK_NONE);
+	l = lwgeom_simplify(g, 10, LW_TRUE);
+	ewkt = lwgeom_to_ewkt(l);
+	CU_ASSERT_STRING_EQUAL(ewkt, "LINESTRING(0 0,0 0)");
+	lwgeom_free(g);
+	lwgeom_free(l);
+	lwfree(ewkt);
 
-		/* Simplify but only so far... */
-		g = lwgeom_from_wkt("POLYGON((0 0, 1 0, 1 1, 0 1, 0 0))", LW_PARSER_CHECK_NONE);
-		l = lwgeom_simplify(g, 10, LW_TRUE);
-		ewkt = lwgeom_to_ewkt(l);
-		CU_ASSERT_STRING_EQUAL(ewkt, "POLYGON((0 0,1 0,1 1,0 0))");
-		lwgeom_free(g);
-		lwgeom_free(l);
-		lwfree(ewkt);
+	/* Simplify but only so far... */
+	g = lwgeom_from_wkt("POLYGON((0 0, 1 0, 1 1, 0 1, 0 0))", LW_PARSER_CHECK_NONE);
+	l = lwgeom_simplify(g, 10, LW_TRUE);
+	ewkt = lwgeom_to_ewkt(l);
+	CU_ASSERT_STRING_EQUAL(ewkt, "POLYGON((0 0,1 0,1 1,0 0))");
+	lwgeom_free(g);
+	lwgeom_free(l);
+	lwfree(ewkt);
 
-		/* Simplify and collapse */
-		g = lwgeom_from_wkt("LINESTRING(0 0, 1 0, 1 1, 0 1, 0 0)", LW_PARSER_CHECK_NONE);
-		l = lwgeom_simplify(g, 10, LW_FALSE);
-		CU_ASSERT_EQUAL(l, NULL);
-		lwgeom_free(g);
-		lwgeom_free(l);
+	/* Simplify and collapse */
+	g = lwgeom_from_wkt("LINESTRING(0 0, 1 0, 1 1, 0 1, 0 0)", LW_PARSER_CHECK_NONE);
+	l = lwgeom_simplify(g, 10, LW_FALSE);
+	CU_ASSERT_EQUAL(l, NULL);
+	lwgeom_free(g);
+	lwgeom_free(l);
 
-		/* Simplify and collapse */
-		g = lwgeom_from_wkt("POLYGON((0 0, 1 0, 1 1, 0 1, 0 0))", LW_PARSER_CHECK_NONE);
-		l = lwgeom_simplify(g, 10, LW_FALSE);
-		CU_ASSERT_EQUAL(l, NULL);
-		lwgeom_free(g);
-		lwgeom_free(l);
+	/* Simplify and collapse */
+	g = lwgeom_from_wkt("POLYGON((0 0, 1 0, 1 1, 0 1, 0 0))", LW_PARSER_CHECK_NONE);
+	l = lwgeom_simplify(g, 10, LW_FALSE);
+	CU_ASSERT_EQUAL(l, NULL);
+	lwgeom_free(g);
+	lwgeom_free(l);
 
-		/* Not simplifiable */
-		g = lwgeom_from_wkt("LINESTRING(0 0, 50 1.00001, 100 0)", LW_PARSER_CHECK_NONE);
-		l = lwgeom_simplify(g, 1.0, LW_FALSE);
-		ewkt = lwgeom_to_ewkt(l);
-		CU_ASSERT_STRING_EQUAL(ewkt, "LINESTRING(0 0,50 1.00001,100 0)");
-		lwgeom_free(g);
-		lwgeom_free(l);
-		lwfree(ewkt);
+	/* Not simplifiable */
+	g = lwgeom_from_wkt("LINESTRING(0 0, 50 1.00001, 100 0)", LW_PARSER_CHECK_NONE);
+	l = lwgeom_simplify(g, 1.0, LW_FALSE);
+	ewkt = lwgeom_to_ewkt(l);
+	CU_ASSERT_STRING_EQUAL(ewkt, "LINESTRING(0 0,50 1.00001,100 0)");
+	lwgeom_free(g);
+	lwgeom_free(l);
+	lwfree(ewkt);
 
-		/* Simplifiable */
-		g = lwgeom_from_wkt("LINESTRING(0 0,50 0.99999,100 0)", LW_PARSER_CHECK_NONE);
-		l = lwgeom_simplify(g, 1.0, LW_FALSE);
-		ewkt = lwgeom_to_ewkt(l);
-		CU_ASSERT_STRING_EQUAL(ewkt, "LINESTRING(0 0,100 0)");
-		lwgeom_free(g);
-		lwgeom_free(l);
-		lwfree(ewkt);
+	/* Simplifiable */
+	g = lwgeom_from_wkt("LINESTRING(0 0,50 0.99999,100 0)", LW_PARSER_CHECK_NONE);
+	l = lwgeom_simplify(g, 1.0, LW_FALSE);
+	ewkt = lwgeom_to_ewkt(l);
+	CU_ASSERT_STRING_EQUAL(ewkt, "LINESTRING(0 0,100 0)");
+	lwgeom_free(g);
+	lwgeom_free(l);
+	lwfree(ewkt);
 }
 
 
@@ -1002,31 +1115,99 @@ static void test_median_handles_3d_correctly(void)
 	do_median_dims_check("MULTIPOINT ZM ((1 3 4 5), (4 7 8 6), (2 9 1 7), (0 4 4 8), (2 2 3 9))", 3);
 }
 
-static void do_median_test(char* input, char* expected)
+static double
+test_weighted_distance(const POINT4D* curr, const POINT4D* points, uint32_t npoints)
 {
-	LWGEOM* g = lwgeom_from_wkt(input, LW_PARSER_CHECK_NONE);
-	LWPOINT* expected_result = lwgeom_as_lwpoint(lwgeom_from_wkt(expected, LW_PARSER_CHECK_NONE));
-	POINT3DZ actual_pt;
-	POINT3DZ expected_pt;
-
-	LWPOINT* result = lwgeom_median(g, FP_TOLERANCE / 10.0, 1000, LW_TRUE);
-	int passed = LW_TRUE;
-
-	lwpoint_getPoint3dz_p(result, &actual_pt);
-	lwpoint_getPoint3dz_p(expected_result, &expected_pt);
-
-	passed = passed && lwgeom_is_empty((LWGEOM*) expected_result) == lwgeom_is_empty((LWGEOM*) result);
-	passed = passed && (lwgeom_has_z((LWGEOM*) expected_result) == lwgeom_has_z((LWGEOM*) result));
-
-	if (!lwgeom_is_empty((LWGEOM*) result))
+	double distance = 0.0;
+	uint32_t i;
+	for (i = 0; i < npoints; i++)
 	{
-		passed = passed && FP_EQUALS(actual_pt.x, expected_pt.x);
-		passed = passed && FP_EQUALS(actual_pt.y, expected_pt.y);
-		passed = passed && (!lwgeom_has_z((LWGEOM*) expected_result) || FP_EQUALS(actual_pt.z, expected_pt.z));
+		distance += distance3d_pt_pt((POINT3D*)curr, (POINT3D*)&points[i]) * points[i].m;
 	}
 
-	if (!passed)
-		printf("median_test expected %s got %s\n", lwgeom_to_ewkt((LWGEOM*) expected_result), lwgeom_to_ewkt((LWGEOM*) result));
+	return distance;
+}
+
+static void do_median_test(char* input, char* expected, int fail_if_not_converged, int iter_count)
+{
+	cu_error_msg_reset();
+	LWGEOM* g = lwgeom_from_wkt(input, LW_PARSER_CHECK_NONE);
+	LWPOINT* expected_result = NULL;
+	POINT4D actual_pt;
+	POINT4D expected_pt;
+	const double tolerance = FP_TOLERANCE / 10.0;
+
+	LWPOINT* result = lwgeom_median(g, tolerance, iter_count, fail_if_not_converged);
+	int passed = LW_FALSE;
+
+	if (expected != NULL)
+	{
+		expected_result = lwgeom_as_lwpoint(lwgeom_from_wkt(expected, LW_PARSER_CHECK_NONE));
+		lwpoint_getPoint4d_p(expected_result, &expected_pt);
+	}
+	if (result != NULL)
+	{
+		lwpoint_getPoint4d_p(result, &actual_pt);
+	}
+
+	if (result != NULL && expected != NULL) /* got something, expecting something */
+	{
+		passed = LW_TRUE;
+		passed = passed && lwgeom_is_empty((LWGEOM*) expected_result) == lwgeom_is_empty((LWGEOM*) result);
+		passed = passed && (lwgeom_has_z((LWGEOM*) expected_result) == lwgeom_has_z((LWGEOM*) result));
+
+		if (passed && !lwgeom_is_empty((LWGEOM*) result))
+		{
+			if (g->type == POINTTYPE)
+			{
+				passed &= fabs(actual_pt.x - expected_pt.x) < tolerance;
+				passed &= fabs(actual_pt.y - expected_pt.y) < tolerance;
+				passed &= (!lwgeom_has_z((LWGEOM*) expected_result) || fabs(actual_pt.z - expected_pt.z) < tolerance);
+				passed &= (!lwgeom_has_m((LWGEOM*) expected_result) || fabs(actual_pt.m - expected_pt.m) < tolerance);
+			}
+			else
+			{
+				/* Check that the difference between the obtained geometric
+				median and the expected point is within tolerance */
+				uint32_t npoints = 1;
+				int input_empty = LW_TRUE;
+				POINT4D* points = lwmpoint_extract_points_4d(lwgeom_as_lwmpoint(g), &npoints, &input_empty);
+				double distance_expected = test_weighted_distance(&expected_pt, points, npoints);
+				double distance_result = test_weighted_distance(&actual_pt, points, npoints);
+
+				passed = distance_result <= (1.0 + tolerance) * distance_expected;
+				if (!passed)
+				{
+					printf("Diff: Got %.10f Expected %.10f\n", distance_result, distance_expected);
+				}
+				lwfree(points);
+			}
+		}
+
+		if (!passed)
+		{
+			printf("median_test input %s (parsed %s) expected %s got %s\n",
+				input, lwgeom_to_ewkt(g),
+				lwgeom_to_ewkt((LWGEOM*) expected_result),
+				lwgeom_to_ewkt((LWGEOM*) result));
+		}
+
+	}
+	else if (result == NULL && expected == NULL) /* got nothing, expecting nothing */
+	{
+		passed = LW_TRUE;
+	}
+	else if (result != NULL && expected == NULL) /* got something, expecting nothing */
+	{
+		passed = LW_FALSE;
+		printf("median_test input %s (parsed %s) expected NULL got %s\n", input, lwgeom_to_ewkt(g), lwgeom_to_ewkt((LWGEOM*) result));
+	}
+	else if (result == NULL && expected != NULL) /* got nothing, expecting something */
+	{
+		passed = LW_FALSE;
+		printf("%s", cu_error_msg);
+		printf("median_test input %s (parsed %s) expected %s got NULL\n", input, lwgeom_to_ewkt(g), lwgeom_to_ewkt((LWGEOM*) expected_result));
+	}
 
 	CU_ASSERT_TRUE(passed);
 
@@ -1043,24 +1224,94 @@ static void test_median_robustness(void)
 	 * Because the algorithm uses the centroid as a starting point, this situation will
 	 * occur in the test case below.
 	 */
-	do_median_test("MULTIPOINT ((0 -1), (0 0), (0 1))", "POINT (0 0)");
+	do_median_test("MULTIPOINT ((0 -1), (0 0), (0 1))", "POINT (0 0)", LW_TRUE, 1000);
 
 	/* Same as above but 3D, and shifter */
-	do_median_test("MULTIPOINT ((1 -1 3), (1 0 2), (2 1 1))", "POINT (1 0 2)");
+	do_median_test("MULTIPOINT ((1 -1 3), (1 0 2), (2 1 1))", "POINT (1 0 2)", LW_TRUE, 1000);
 
 	/* Starting point is duplicated */
-	do_median_test("MULTIPOINT ((0 -1), (0 0), (0 0), (0 1))", "POINT (0 0)");
+	do_median_test("MULTIPOINT ((0 -1), (0 0), (0 0), (0 1))", "POINT (0 0)", LW_TRUE, 1000);
 
 	/* Cube */
 	do_median_test("MULTIPOINT ((10 10 10), (10 20 10), (20 10 10), (20 20 10), (10 10 20), (10 20 20), (20 10 20), (20 20 20))",
-				   "POINT (15 15 15)");
+				   "POINT (15 15 15)", LW_TRUE, 1000);
 
 	/* Some edge cases */
-	do_median_test("MULTIPOINT EMPTY", "POINT EMPTY");
-	do_median_test("MULTIPOINT (EMPTY)", "POINT EMPTY");
-	do_median_test("POINT (7 6)", "POINT (7 6)");
-	do_median_test("POINT (7 6 2)", "POINT (7 6 2)");
-	do_median_test("MULTIPOINT ((7 6 2), EMPTY)", "POINT (7 6 2)");
+	do_median_test("POINT (7 6)", "POINT (7 6)", LW_TRUE, 1000);
+	do_median_test("POINT (7 6 2)", "POINT (7 6 2)", LW_TRUE, 1000);
+	do_median_test("MULTIPOINT ((7 6 2), EMPTY)", "POINT (7 6 2)", LW_TRUE, 1000);
+
+	/* Empty input */
+	do_median_test("MULTIPOINT EMPTY", "POINT EMPTY", LW_FALSE, 1000);
+	do_median_test("MULTIPOINT (EMPTY)", "POINT EMPTY", LW_FALSE, 1000);
+	do_median_test("MULTIPOINT EMPTY", "POINT EMPTY", LW_TRUE, 1000);
+	do_median_test("MULTIPOINT (EMPTY)", "POINT EMPTY", LW_TRUE, 1000);
+	do_median_test("MULTIPOINT ZM (1 -1 3 1, 1 0 2 7, 2 1 1 1, EMPTY)", "POINT (1 0 2)", LW_TRUE, 1000);
+
+	/* Weighted input */
+	do_median_test("MULTIPOINT ZM (1 -1 3 1, 1 0 2 7, 2 1 1 1)", "POINT (1 0 2)", LW_TRUE, 1000);
+	do_median_test("MULTIPOINT ZM (-1 1 -3 1, -1 0 -2 7, -2 -1 -1 1)", "POINT (-1 0 -2)", LW_TRUE, 1000);
+	do_median_test("MULTIPOINT ZM (-1 1 -3 1, -1 0 -2 7, -2 -1 -1 0.5, -2 -1 -1 0.5)", "POINT (-1 0 -2)", LW_TRUE, 1000);
+
+	/* Point that is replaced by two half-weighted */
+	do_median_test("MULTIPOINT ZM ((0 -1 0 1), (0 0 0 1), (0 1 0 0.5), (0 1 0 0.5))", "POINT (0 0 0)", LW_TRUE, 1000);
+	/* Point is doubled and then erased by negative weight */
+	do_median_test("MULTIPOINT ZM ((1 -1 3 1), (1 0 2 7), (2 1 1 2), (2 1 1 -1))", NULL, LW_TRUE, 1000);
+	do_median_test("MULTIPOINT ZM ((1 -1 3 1), (1 0 2 7), (2 1 1 2), (2 1 1 -1))", NULL, LW_FALSE, 1000);
+	/* Weightless input won't converge */
+	do_median_test("MULTIPOINT ZM ((0 -1 0 0), (0 0 0 0), (0 0 0 0), (0 1 0 0))", NULL, LW_FALSE, 1000);
+	do_median_test("MULTIPOINT ZM ((0 -1 0 0), (0 0 0 0), (0 0 0 0), (0 1 0 0))", NULL, LW_TRUE, 1000);
+	/* Negative weight won't converge */
+	do_median_test("MULTIPOINT ZM ((0 -1 0 -1), (0 0 0 -1), (0 1 0 -1))", NULL, LW_FALSE, 1000);
+	do_median_test("MULTIPOINT ZM ((0 -1 0 -1), (0 0 0 -1), (0 1 0 -1))", NULL, LW_TRUE, 1000);
+
+	/* Bind convergence too tightly */
+	do_median_test("MULTIPOINT ((0 0), (1 1), (0 1), (2 2))", "POINT(0.75 1.0)", LW_FALSE, 0);
+	do_median_test("MULTIPOINT ((0 0), (1 1), (0 1), (2 2))", NULL, LW_TRUE, 1);
+	/* Unsupported geometry type */
+	do_median_test("POLYGON((1 0,0 1,1 2,2 1,1 0))", NULL, LW_TRUE, 1000);
+	do_median_test("POLYGON((1 0,0 1,1 2,2 1,1 0))", NULL, LW_FALSE, 1000);
+
+	/* Median point is included */
+	do_median_test("MULTIPOINT ZM ("
+		"(1480 0 200 100),"
+		"(620 0  200 100),"
+		"(1000 0 -200 100),"
+		"(1000 0 -590 100),"
+		"(1025 0  65 100),"
+		"(1025 0 -65 100)"
+		")",
+	"POINT (1025 0 -65)", LW_TRUE, 10000);
+
+#if 0
+	/* Leads to invalid result (0 0 0) with 80bit (fmulp + faddp) precision. ok with 64 bit float ops */
+	do_median_test("MULTIPOINT ZM ("
+		"(0 0 20000 0.5),"
+		"(0 0 59000 0.5),"
+		"(0 -3000 -3472.22222222222262644208967685699462890625 1),"
+		"(0  3000  3472.22222222222262644208967685699462890625 1),"
+		"(0 0 -1644.736842105263121993630193173885345458984375 1),"
+		"(0 0  1644.736842105263121993630193173885345458984375 1),"
+		"(0  48000 -20000 1.3),"
+		"(0 -48000 -20000 1.3)"
+		")",
+	"POINT (0 0 0)", LW_TRUE, 10000);
+#endif
+
+#if 0
+	/* Leads to invalid result (0 0 0) with 64bit (vfmadd231sd) precision. Ok with 80 bit float ops */
+	do_median_test("MULTIPOINT ZM ("
+		"(0 0 20000 0.5),"
+		"(0 0 59000 0.5),"
+		"(0 -3000 -3472.22222222222262644208967685699462890625 1),"
+		"(0  3000  3472.22222222222262644208967685699462890625 1),"
+		"(0 -0.00000000000028047739569477638384522295466033823196 -1644.736842105263121993630193173885345458984375 1),"
+		"(0  0.00000000000028047739569477638384522295466033823196  1644.736842105263121993630193173885345458984375 1),"
+		"(0  48000 -20000 1.3),"
+		"(0 -48000 -20000 1.3)"
+		")",
+	"POINT (0 0 0)", LW_TRUE, 10000);
+#endif
 }
 
 static void test_point_density(void)
@@ -1183,13 +1434,59 @@ static void test_kmeans(void)
 	return;
 }
 
+static void test_trim_bits(void)
+{
+	POINTARRAY *pta = ptarray_construct_empty(LW_TRUE, LW_TRUE, 2);
+	POINT4D pt;
+	LWLINE *line;
+	int precision;
+	uint32_t i;
+
+	pt.x = 1.2345678901234;
+	pt.y = 2.3456789012345;
+	pt.z = 3.4567890123456;
+	pt.m = 4.5678901234567;
+
+	ptarray_insert_point(pta, &pt, 0);
+
+	pt.x *= 3;
+	pt.y *= 3;
+	pt.y *= 3;
+	pt.z *= 3;
+
+	ptarray_insert_point(pta, &pt, 1);
+
+	line = lwline_construct(0, NULL, pta);
+
+	for (precision = -15; precision <= 15; precision++)
+	{
+		LWLINE *line2 = (LWLINE*) lwgeom_clone_deep((LWGEOM*) line);
+		lwgeom_trim_bits_in_place((LWGEOM*) line2, precision, precision, precision, precision);
+
+		for (i = 0; i < line->points->npoints; i++)
+		{
+			POINT4D pt1 = getPoint4d(line->points, i);
+			POINT4D pt2 = getPoint4d(line2->points, i);
+
+			CU_ASSERT_DOUBLE_EQUAL(pt1.x, pt2.x, pow(10, -1*precision));
+			CU_ASSERT_DOUBLE_EQUAL(pt1.y, pt2.y, pow(10, -1*precision));
+			CU_ASSERT_DOUBLE_EQUAL(pt1.z, pt2.z, pow(10, -1*precision));
+			CU_ASSERT_DOUBLE_EQUAL(pt1.m, pt2.m, pow(10, -1*precision));
+		}
+
+		lwline_free(line2);
+	}
+
+	lwline_free(line);
+}
+
 /*
 ** Used by test harness to register the tests in this file.
 */
 void algorithms_suite_setup(void);
 void algorithms_suite_setup(void)
 {
-	CU_pSuite suite = CU_add_suite("computational_geometry", init_cg_suite, clean_cg_suite);
+	CU_pSuite suite = CU_add_suite("algorithm", init_cg_suite, clean_cg_suite);
 	PG_ADD_TEST(suite,test_lw_segment_side);
 	PG_ADD_TEST(suite,test_lw_segment_intersects);
 	PG_ADD_TEST(suite,test_lwline_crossing_short_lines);
@@ -1198,6 +1495,7 @@ void algorithms_suite_setup(void)
 	PG_ADD_TEST(suite,test_lwpoint_set_ordinate);
 	PG_ADD_TEST(suite,test_lwpoint_get_ordinate);
 	PG_ADD_TEST(suite,test_point_interpolate);
+	PG_ADD_TEST(suite,test_lwline_interpolate_points);
 	PG_ADD_TEST(suite,test_lwline_clip);
 	PG_ADD_TEST(suite,test_lwline_clip_big);
 	PG_ADD_TEST(suite,test_lwmline_clip);
@@ -1213,4 +1511,6 @@ void algorithms_suite_setup(void)
 	PG_ADD_TEST(suite,test_median_handles_3d_correctly);
 	PG_ADD_TEST(suite,test_median_robustness);
 	PG_ADD_TEST(suite,test_lwpoly_construct_circle);
+	PG_ADD_TEST(suite,test_trim_bits);
+	PG_ADD_TEST(suite,test_lwgeom_remove_repeated_points);
 }
