@@ -18,7 +18,6 @@
 
 static void test_lwgeom_delaunay_triangulation(void)
 {
-#if POSTGIS_GEOS_VERSION >= 34
 	LWGEOM *in, *tmp, *out;
 	char *wkt, *exp_wkt;
 
@@ -42,8 +41,6 @@ static void test_lwgeom_delaunay_triangulation(void)
 	}
 	CU_ASSERT_STRING_EQUAL(wkt, exp_wkt);
 	lwfree(wkt);
-
-#endif /* POSTGIS_GEOS_VERSION >= 34 */
 }
 
 static void test_lwgeom_voronoi_diagram(void)
@@ -83,10 +80,11 @@ static void test_lwgeom_voronoi_diagram_custom_envelope(void)
 #endif /* POSTGIS_GEOS_VERSION >= 35 */
 }
 
+#if POSTGIS_GEOS_VERSION >= 35
 static void assert_empty_diagram(char* wkt, double tolerance)
 {
 	LWGEOM* in = lwgeom_from_wkt(wkt, LW_PARSER_CHECK_NONE);
-	LWGEOM* out = lwgeom_voronoi_diagram(in, NULL, 0, 0);
+	LWGEOM* out = lwgeom_voronoi_diagram(in, NULL, tolerance, 0);
 
 	CU_ASSERT_TRUE(lwgeom_is_collection(out));
 	CU_ASSERT_EQUAL(COLLECTIONTYPE, lwgeom_get_type(out));
@@ -94,6 +92,7 @@ static void assert_empty_diagram(char* wkt, double tolerance)
 	lwgeom_free(in);
 	lwgeom_free(out);
 }
+#endif /* POSTGIS_GEOS_VERSION >= 35 */
 
 static void test_lwgeom_voronoi_diagram_expected_empty(void)
 {
