@@ -27,17 +27,6 @@
 #include "lwgeom_log.h"
 #include <ctype.h> /* for tolower */
 
-
-/**
-* Returns -1 if n < 0.0 and 1 if n > 0.0
-*/
-int signum(double n)
-{
-	if( n < 0 ) return -1;
-	if( n > 0 ) return 1;
-	return 0;
-}
-
 int
 p4d_same(const POINT4D *p1, const POINT4D *p2)
 {
@@ -75,10 +64,7 @@ p2d_same(const POINT2D *p1, const POINT2D *p2)
 int lw_segment_side(const POINT2D *p1, const POINT2D *p2, const POINT2D *q)
 {
 	double side = ( (q->x - p1->x) * (p2->y - p1->y) - (p2->x - p1->x) * (q->y - p1->y) );
-	if ( side == 0.0 )
-		return 0;
-	else
-		return signum(side);
+	return SIGNUM(side);
 }
 
 /**
@@ -233,9 +219,10 @@ int lw_arc_side(const POINT2D *A1, const POINT2D *A2, const POINT2D *A3, const P
 /**
 * Determines the center of the circle defined by the three given points.
 * In the event the circle is complete, the midpoint of the segment defined
-* by the first and second points is returned.  If the points are colinear,
-* as determined by equal slopes, then NULL is returned.  If the interior
-* point is coincident with either end point, they are taken as colinear.
+* by the first and second points is returned.  If the points are collinear,
+* as determined by equal slopes, then -1.0 is returned.  If the interior
+* point is coincident with either end point, they are taken as collinear.
+* For non-collinear cases, arc radious is returned.
 */
 double
 lw_arc_center(const POINT2D *p1, const POINT2D *p2, const POINT2D *p3, POINT2D *result)
@@ -294,7 +281,7 @@ int
 pt_in_ring_2d(const POINT2D *p, const POINTARRAY *ring)
 {
 	int cn = 0;    /* the crossing number counter */
-	int i;
+	uint32_t i;
 	const POINT2D *v1, *v2;
 	const POINT2D *first, *last;
 
@@ -473,13 +460,16 @@ int lw_segment_intersects(const POINT2D *p1, const POINT2D *p2, const POINT2D *q
 */
 int lwline_crossing_direction(const LWLINE *l1, const LWLINE *l2)
 {
-	int i = 0, j = 0;
+	uint32_t i = 0, j = 0;
 	const POINT2D *p1, *p2, *q1, *q2;
 	POINTARRAY *pa1 = NULL, *pa2 = NULL;
 	int cross_left = 0;
 	int cross_right = 0;
 	int first_cross = 0;
 	int this_cross = 0;
+#if POSTGIS_DEBUG_LEVEL >= 4
+	char *geom_ewkt;
+#endif
 
 	pa1 = (POINTARRAY*)l1->points;
 	pa2 = (POINTARRAY*)l2->points;
@@ -488,8 +478,14 @@ int lwline_crossing_direction(const LWLINE *l1, const LWLINE *l2)
 	if ( pa1->npoints < 2 || pa2->npoints < 2 )
 		return LINE_NO_CROSS;
 
-	LWDEBUGF(4, "l1 = %s", lwgeom_to_ewkt((LWGEOM*)l1));
-	LWDEBUGF(4, "l2 = %s", lwgeom_to_ewkt((LWGEOM*)l2));
+#if POSTGIS_DEBUG_LEVEL >= 4
+	geom_ewkt = lwgeom_to_ewkt((LWGEOM*)l1);
+	LWDEBUGF(4, "l1 = %s", geom_ewkt);
+	lwfree(geom_ewkt);
+	geom_ewkt = lwgeom_to_ewkt((LWGEOM*)l2);
+	LWDEBUGF(4, "l2 = %s", geom_ewkt);
+	lwfree(geom_ewkt);
+#endif
 
 	/* Initialize first point of q */
 	q1 = getPoint2d_cp(pa2, 0);
@@ -531,7 +527,7 @@ int lwline_crossing_direction(const LWLINE *l1, const LWLINE *l2)
 
 			/*
 			** Crossing at a co-linearity can be turned handled by extending
-			** segment to next vertext and seeing if the end points straddle
+			** segment to next vertex and seeing if the end points straddle
 			** the co-linear segment.
 			*/
 			if ( this_cross == SEG_COLINEAR )
@@ -680,7 +676,7 @@ unsigned int geohash_point_as_int(POINT2D *pt)
 			mid = (lon[0] + lon[1]) / 2;
 			if (longitude > mid)
 			{
-				ch |= 0x0001 << bit;
+				ch |= 0x0001u << bit;
 				lon[0] = mid;
 			}
 			else
