@@ -2353,7 +2353,7 @@ lwgeom_subdivide_recursive(const LWGEOM *geom, uint8_t dimension, uint32_t maxve
 		lwpoly = (LWPOLY *)geom;
 
 		/* if there are more points in holes than in outer ring */
-		if (nvertices > 2 * lwpoly->rings[0]->npoints)
+		if (nvertices >= 2 * lwpoly->rings[0]->npoints)
 		{
 			/* trim holes starting from biggest */
 			for (i = 1; i < lwpoly->nrings; i++)
@@ -2402,7 +2402,7 @@ lwgeom_subdivide_recursive(const LWGEOM *geom, uint8_t dimension, uint32_t maxve
 	clipped = lwgeom_intersection(geom, subbox);
 	lwgeom_simplify_in_place(clipped, 0.0, LW_TRUE);
 	lwgeom_free(subbox);
-	if (clipped)
+	if (clipped && !lwgeom_is_empty(clipped))
 	{
 		n += lwgeom_subdivide_recursive(clipped, dimension, maxvertices, depth, col);
 		lwgeom_free(clipped);
@@ -2412,7 +2412,7 @@ lwgeom_subdivide_recursive(const LWGEOM *geom, uint8_t dimension, uint32_t maxve
 	clipped = lwgeom_intersection(geom, subbox);
 	lwgeom_simplify_in_place(clipped, 0.0, LW_TRUE);
 	lwgeom_free(subbox);
-	if (clipped)
+	if (clipped && !lwgeom_is_empty(clipped))
 	{
 		n += lwgeom_subdivide_recursive(clipped, dimension, maxvertices, depth, col);
 		lwgeom_free(clipped);
