@@ -19,6 +19,7 @@
  **********************************************************************
  *
  * Copyright 2001-2006 Refractions Research Inc.
+ * Copyright 2017 Darafei Praliaskouski <me@komzpa.net>
  *
  **********************************************************************/
 
@@ -60,7 +61,7 @@ next_float_down(double d)
 }
 
 /*
- * Returns the float thats very close to the input, but >=.
+ * Returns the float that's very close to the input, but >=.
  * handles the funny differences in float4 and float8 reps.
  */
 inline float
@@ -92,7 +93,7 @@ next_float_up(double d)
  * NOTE: point is a real POINT3D *not* a pointer
  */
 POINT4D
-getPoint4d(const POINTARRAY *pa, int n)
+getPoint4d(const POINTARRAY *pa, uint32_t n)
 {
 	POINT4D result;
 	getPoint4d_p(pa, n, &result);
@@ -109,7 +110,7 @@ getPoint4d(const POINTARRAY *pa, int n)
  * @return 0 on error, 1 on success
  */
 int
-getPoint4d_p(const POINTARRAY *pa, int n, POINT4D *op)
+getPoint4d_p(const POINTARRAY *pa, uint32_t n, POINT4D *op)
 {
 	uint8_t *ptr;
 	int zmflag;
@@ -120,7 +121,7 @@ getPoint4d_p(const POINTARRAY *pa, int n, POINT4D *op)
 		return 0;
 	}
 
-	if ( (n<0) || (n>=pa->npoints))
+	if ( n>=pa->npoints )
 	{
 		lwnotice("%s [%d] called with n=%d and npoints=%d", __FILE__, __LINE__, n, pa->npoints);
 		return 0;
@@ -173,7 +174,7 @@ getPoint4d_p(const POINTARRAY *pa, int n, POINT4D *op)
  * NOTE: point is a real POINT3DZ *not* a pointer
  */
 POINT3DZ
-getPoint3dz(const POINTARRAY *pa, int n)
+getPoint3dz(const POINTARRAY *pa, uint32_t n)
 {
 	POINT3DZ result;
 	getPoint3dz_p(pa, n, &result);
@@ -187,7 +188,7 @@ getPoint3dz(const POINTARRAY *pa, int n)
  * NOTE: point is a real POINT3DZ *not* a pointer
  */
 POINT3DM
-getPoint3dm(const POINTARRAY *pa, int n)
+getPoint3dm(const POINTARRAY *pa, uint32_t n)
 {
 	POINT3DM result;
 	getPoint3dm_p(pa, n, &result);
@@ -201,7 +202,7 @@ getPoint3dm(const POINTARRAY *pa, int n)
  * NOTE: this will modify the point3dz pointed to by 'point'.
  */
 int
-getPoint3dz_p(const POINTARRAY *pa, int n, POINT3DZ *op)
+getPoint3dz_p(const POINTARRAY *pa, uint32_t n, POINT3DZ *op)
 {
 	uint8_t *ptr;
 
@@ -211,7 +212,7 @@ getPoint3dz_p(const POINTARRAY *pa, int n, POINT3DZ *op)
 		return 0;
 	}
 
-	if ( (n<0) || (n>=pa->npoints))
+	if ( n>=pa->npoints )
 	{
 		lwnotice("%s [%d] called with n=%d and npoints=%d", __FILE__, __LINE__, n, pa->npoints);
 		return 0;
@@ -253,7 +254,7 @@ getPoint3dz_p(const POINTARRAY *pa, int n, POINT3DZ *op)
  * NOTE: this will modify the point3dm pointed to by 'point'.
  */
 int
-getPoint3dm_p(const POINTARRAY *pa, int n, POINT3DM *op)
+getPoint3dm_p(const POINTARRAY *pa, uint32_t n, POINT3DM *op)
 {
 	uint8_t *ptr;
 	int zmflag;
@@ -264,7 +265,7 @@ getPoint3dm_p(const POINTARRAY *pa, int n, POINT3DM *op)
 		return 0;
 	}
 
-	if ( (n<0) || (n>=pa->npoints))
+	if ( n>=pa->npoints )
 	{
 		lwnotice("%s [%d] called with n=%d and npoints=%d", __FILE__, __LINE__, n, pa->npoints);
 		return 0;
@@ -320,7 +321,7 @@ getPoint3dm_p(const POINTARRAY *pa, int n, POINT3DM *op)
  * NOTE: point is a real POINT2D *not* a pointer
  */
 POINT2D
-getPoint2d(const POINTARRAY *pa, int n)
+getPoint2d(const POINTARRAY *pa, uint32_t n)
 {
 	const POINT2D *result;
 	result = getPoint2d_cp(pa, n);
@@ -334,7 +335,7 @@ getPoint2d(const POINTARRAY *pa, int n)
  * NOTE: this will modify the point2d pointed to by 'point'.
  */
 int
-getPoint2d_p(const POINTARRAY *pa, int n, POINT2D *point)
+getPoint2d_p(const POINTARRAY *pa, uint32_t n, POINT2D *point)
 {
 	if ( ! pa )
 	{
@@ -342,7 +343,7 @@ getPoint2d_p(const POINTARRAY *pa, int n, POINT2D *point)
 		return 0;
 	}
 
-	if ( (n<0) || (n>=pa->npoints))
+	if ( n>=pa->npoints )
 	{
 		lwnotice("%s [%d] called with n=%d and npoints=%d", __FILE__, __LINE__, n, pa->npoints);
 		return 0;
@@ -360,13 +361,13 @@ getPoint2d_p(const POINTARRAY *pa, int n, POINT2D *point)
 * values, only read them.
 */
 const POINT2D*
-getPoint2d_cp(const POINTARRAY *pa, int n)
+getPoint2d_cp(const POINTARRAY *pa, uint32_t n)
 {
 	if ( ! pa ) return 0;
 
-	if ( (n<0) || (n>=pa->npoints))
+	if ( n>=pa->npoints )
 	{
-		lwerror("getPoint2D_const_p: point offset out of range");
+		lwerror("getPoint2d_cp: point offset out of range");
 		return 0; /*error */
 	}
 
@@ -374,7 +375,7 @@ getPoint2d_cp(const POINTARRAY *pa, int n)
 }
 
 const POINT3DZ*
-getPoint3dz_cp(const POINTARRAY *pa, int n)
+getPoint3dz_cp(const POINTARRAY *pa, uint32_t n)
 {
 	if ( ! pa ) return 0;
 
@@ -384,7 +385,7 @@ getPoint3dz_cp(const POINTARRAY *pa, int n)
 		return 0; /*error */
 	}
 
-	if ( (n<0) || (n>=pa->npoints))
+	if ( n>=pa->npoints )
 	{
 		lwerror("getPoint3dz_cp: point offset out of range");
 		return 0; /*error */
@@ -393,29 +394,26 @@ getPoint3dz_cp(const POINTARRAY *pa, int n)
 	return (const POINT3DZ*)getPoint_internal(pa, n);
 }
 
-
 const POINT4D*
-getPoint4d_cp(const POINTARRAY *pa, int n)
+getPoint4d_cp(const POINTARRAY* pa, uint32_t n)
 {
-	if ( ! pa ) return 0;
+	if (!pa) return 0;
 
-	if ( ! (FLAGS_GET_Z(pa->flags) && FLAGS_GET_Z(pa->flags)) )
+	if (!(FLAGS_GET_Z(pa->flags) && FLAGS_GET_M(pa->flags)))
 	{
-		lwerror("getPoint3dz_cp: no Z and M coordinates in point array");
+		lwerror("getPoint4d_cp: no Z and M coordinates in point array");
 		return 0; /*error */
 	}
 
-	if ( (n<0) || (n>=pa->npoints))
+	if (n >= pa->npoints)
 	{
-		lwerror("getPoint3dz_cp: point offset out of range");
+		lwerror("getPoint4d_cp: point offset out of range");
 		return 0; /*error */
 	}
 
 	return (const POINT4D*)getPoint_internal(pa, n);
 }
 
-
-
 /*
  * set point N to the given value
  * NOTE that the pointarray can be of any
@@ -424,10 +422,10 @@ getPoint4d_cp(const POINTARRAY *pa, int n)
  *
  */
 void
-ptarray_set_point4d(POINTARRAY *pa, int n, const POINT4D *p4d)
+ptarray_set_point4d(POINTARRAY *pa, uint32_t n, const POINT4D *p4d)
 {
 	uint8_t *ptr;
-	assert(n >= 0 && n < pa->npoints);
+	assert(n < pa->npoints);
 	ptr=getPoint_internal(pa, n);
 	switch ( FLAGS_GET_ZM(pa->flags) )
 	{
@@ -448,6 +446,42 @@ ptarray_set_point4d(POINTARRAY *pa, int n, const POINT4D *p4d)
 	}
 }
 
+void
+ptarray_copy_point(POINTARRAY *pa, uint32_t from, uint32_t to)
+{
+	int ndims = FLAGS_NDIMS(pa->flags);
+	switch (ndims)
+	{
+		case 2:
+		{
+			POINT2D *p_from = (POINT2D*)(getPoint_internal(pa, from));
+			POINT2D *p_to = (POINT2D*)(getPoint_internal(pa, to));
+			*p_to = *p_from;
+			return;
+		}
+		case 3:
+		{
+			POINT3D *p_from = (POINT3D*)(getPoint_internal(pa, from));
+			POINT3D *p_to = (POINT3D*)(getPoint_internal(pa, to));
+			*p_to = *p_from;
+			return;
+		}
+		case 4:
+		{
+			POINT4D *p_from = (POINT4D*)(getPoint_internal(pa, from));
+			POINT4D *p_to = (POINT4D*)(getPoint_internal(pa, to));
+			*p_to = *p_from;
+			return;
+		}
+		default:
+		{
+			lwerror("%s: unsupported number of dimensions - %d", __func__, ndims);
+			return;
+		}
+	}
+	return;
+}
+
 
 /************************************************
  * debugging routines
@@ -461,7 +495,7 @@ void printBOX3D(BOX3D *box)
 
 void printPA(POINTARRAY *pa)
 {
-	int t;
+	uint32_t t;
 	POINT4D pt;
 	char *mflag;
 
@@ -667,14 +701,10 @@ deparse_hex(uint8_t str, char *result)
  *   F=.2   :    A-I-------B
  */
 void
-interpolate_point4d(POINT4D *A, POINT4D *B, POINT4D *I, double F)
+interpolate_point4d(const POINT4D *A, const POINT4D *B, POINT4D *I, double F)
 {
 #if PARANOIA_LEVEL > 0
-	double absF=fabs(F);
-	if ( absF < 0 || absF > 1 )
-	{
-		lwerror("interpolate_point4d: invalid F (%g)", F);
-	}
+	if (F < 0 || F > 1) lwerror("interpolate_point4d: invalid F (%g)", F);
 #endif
 	I->x=A->x+((B->x-A->x)*F);
 	I->y=A->y+((B->y-A->y)*F);
