@@ -136,15 +136,9 @@ lwline_release(LWLINE *lwline)
 	lwgeom_release(lwline_as_lwgeom(lwline));
 }
 
-void
-lwline_reverse(LWLINE *line)
-{
-	if ( lwline_is_empty(line) ) return;
-	ptarray_reverse(line->points);
-}
 
 LWLINE *
-lwline_segmentize2d(LWLINE *line, double dist)
+lwline_segmentize2d(const LWLINE *line, double dist)
 {
 	POINTARRAY *segmentized = ptarray_segmentize2d(line->points, dist);
 	if ( ! segmentized ) return NULL;
@@ -165,7 +159,7 @@ lwline_same(const LWLINE *l1, const LWLINE *l2)
 LWLINE *
 lwline_from_lwgeom_array(int srid, uint32_t ngeoms, LWGEOM **geoms)
 {
-	int i;
+	uint32_t i;
 	int hasz = LW_FALSE;
 	int hasm = LW_FALSE;
 	POINTARRAY *pa;
@@ -242,7 +236,7 @@ lwline_from_lwgeom_array(int srid, uint32_t ngeoms, LWGEOM **geoms)
 LWLINE *
 lwline_from_ptarray(int srid, uint32_t npoints, LWPOINT **points)
 {
- 	int i;
+ 	uint32_t i;
 	int hasz = LW_FALSE;
 	int hasm = LW_FALSE;
 	POINTARRAY *pa;
@@ -321,13 +315,13 @@ lwline_from_lwmpoint(int srid, const LWMPOINT *mpoint)
 * Returns NULL if the geometry is empty or the index invalid.
 */
 LWPOINT*
-lwline_get_lwpoint(const LWLINE *line, int where)
+lwline_get_lwpoint(const LWLINE *line, uint32_t where)
 {
 	POINT4D pt;
 	LWPOINT *lwpoint;
 	POINTARRAY *pa;
 
-	if ( lwline_is_empty(line) || where < 0 || where >= line->points->npoints )
+	if ( lwline_is_empty(line) || where >= line->points->npoints )
 		return NULL;
 
 	pa = ptarray_construct_empty(FLAGS_GET_Z(line->flags), FLAGS_GET_M(line->flags), 1);
@@ -339,7 +333,7 @@ lwline_get_lwpoint(const LWLINE *line, int where)
 
 
 int
-lwline_add_lwpoint(LWLINE *line, LWPOINT *point, int where)
+lwline_add_lwpoint(LWLINE *line, LWPOINT *point, uint32_t where)
 {
 	POINT4D pt;
 	getPoint4d_p(point->point, 0, &pt);
@@ -350,8 +344,7 @@ lwline_add_lwpoint(LWLINE *line, LWPOINT *point, int where)
 	/* Update the bounding box */
 	if ( line->bbox )
 	{
-		lwgeom_drop_bbox(lwline_as_lwgeom(line));
-		lwgeom_add_bbox(lwline_as_lwgeom(line));
+		lwgeom_refresh_bbox((LWGEOM*)line);
 	}
 
 	return LW_SUCCESS;
@@ -383,8 +376,7 @@ lwline_setPoint4d(LWLINE *line, uint32_t index, POINT4D *newpoint)
 	/* Update the box, if there is one to update */
 	if ( line->bbox )
 	{
-		lwgeom_drop_bbox((LWGEOM*)line);
-		lwgeom_add_bbox((LWGEOM*)line);
+		lwgeom_refresh_bbox((LWGEOM*)line);
 	}
 }
 
@@ -455,13 +447,7 @@ lwline_measured_from_lwline(const LWLINE *lwline, double m_start, double m_end)
 LWGEOM*
 lwline_remove_repeated_points(const LWLINE *lwline, double tolerance)
 {
-	POINTARRAY* npts = ptarray_remove_repeated_points_minpoints(lwline->points, tolerance, 2);
-
-	LWDEBUGF(3, "%s: npts %p", __func__, npts);
-
-	return (LWGEOM*)lwline_construct(lwline->srid,
-	                                 lwline->bbox ? gbox_copy(lwline->bbox) : 0,
-	                                 npts);
+	return lwgeom_remove_repeated_points((LWGEOM*)lwline, tolerance);
 }
 
 int
@@ -530,7 +516,7 @@ int lwline_is_empty(const LWLINE *line)
 }
 
 
-int lwline_count_vertices(LWLINE *line)
+uint32_t lwline_count_vertices(LWLINE *line)
 {
 	assert(line);
 	if ( ! line->points )
@@ -538,44 +524,6 @@ int lwline_count_vertices(LWLINE *line)
 	return line->points->npoints;
 }
 
-LWLINE* lwline_simplify(const LWLINE *iline, double dist, int preserve_collapsed)
-{
-	static const int minvertices = 2; /* TODO: allow setting this */
-	LWLINE *oline;
-	POINTARRAY *pa;
-
-	LWDEBUG(2, "function called");
-
-	/* Skip empty case */
-	if( lwline_is_empty(iline) )
-		return NULL;
-
-	pa = ptarray_simplify(iline->points, dist, minvertices);
-	if ( ! pa ) return NULL;
-
-	/* Make sure single-point collapses have two points */
-	if ( pa->npoints == 1 )
-	{
-		/* Make sure single-point collapses have two points */
-		if ( preserve_collapsed )
-		{
-			POINT4D pt;
-			getPoint4d_p(pa, 0, &pt);
-			ptarray_append_point(pa, &pt, LW_TRUE);
-		}
-		/* Return null for collapse */
-		else
-		{
-			ptarray_free(pa);
-			return NULL;
-		}
-	}
-
-	oline = lwline_construct(iline->srid, NULL, pa);
-	oline->type = iline->type;
-	return oline;
-}
-
 double lwline_length(const LWLINE *line)
 {
 	if ( lwline_is_empty(line) )
@@ -591,20 +539,79 @@ double lwline_length_2d(const LWLINE *line)
 }
 
 
+POINTARRAY* lwline_interpolate_points(const LWLINE *line, double length_fraction, char repeat) {
+	POINT4D pt;
+	uint32_t i;
+	uint32_t points_to_interpolate;
+	uint32_t points_found = 0;
+	double length;
+	double length_fraction_increment = length_fraction;
+	double length_fraction_consumed = 0;
+	char has_z = (char) lwgeom_has_z(lwline_as_lwgeom(line));
+	char has_m = (char) lwgeom_has_m(lwline_as_lwgeom(line));
+	const POINTARRAY* ipa = line->points;
+	POINTARRAY* opa;
 
-LWLINE* lwline_grid(const LWLINE *line, const gridspec *grid)
-{
-	LWLINE *oline;
-	POINTARRAY *opa;
+	/* Empty.InterpolatePoint == Point Empty */
+	if ( lwline_is_empty(line) )
+	{
+		return ptarray_construct_empty(has_z, has_m, 0);
+	}
 
-	opa = ptarray_grid(line->points, grid);
+	/* If distance is one of the two extremes, return the point on that
+	 * end rather than doing any computations
+	 */
+	if ( length_fraction == 0.0 || length_fraction == 1.0 )
+	{
+		if ( length_fraction == 0.0 )
+			getPoint4d_p(ipa, 0, &pt);
+		else
+			getPoint4d_p(ipa, ipa->npoints-1, &pt);
 
-	/* Skip line3d with less then 2 points */
-	if ( opa->npoints < 2 ) return NULL;
+		opa = ptarray_construct(has_z, has_m, 1);
+		ptarray_set_point4d(opa, 0, &pt);
 
-	/* TODO: grid bounding box... */
-	oline = lwline_construct(line->srid, NULL, opa);
+		return opa;
+	}
 
-	return oline;
+	/* Interpolate points along the line */
+	length = ptarray_length_2d(ipa);
+	points_to_interpolate = repeat ? (uint32_t) floor(1 / length_fraction) : 1;
+	opa = ptarray_construct(has_z, has_m, points_to_interpolate);
+
+	const POINT2D* p1 = getPoint2d_cp(ipa, 0);
+	for ( i = 0; i < ipa->npoints - 1 && points_found < points_to_interpolate; i++ )
+	{
+		const POINT2D* p2 = getPoint2d_cp(ipa, i+1);
+		double segment_length_frac = distance2d_pt_pt(p1, p2) / length;
+
+		/* If our target distance is before the total length we've seen
+		 * so far. create a new point some distance down the current
+		 * segment.
+		 */
+		while ( length_fraction < length_fraction_consumed + segment_length_frac && points_found < points_to_interpolate )
+		{
+			POINT4D p1_4d = getPoint4d(ipa, i);
+			POINT4D p2_4d = getPoint4d(ipa, i+1);
+
+			double segment_fraction = (length_fraction - length_fraction_consumed) / segment_length_frac;
+			interpolate_point4d(&p1_4d, &p2_4d, &pt, segment_fraction);
+			ptarray_set_point4d(opa, points_found++, &pt);
+			length_fraction += length_fraction_increment;
+		}
+
+		length_fraction_consumed += segment_length_frac;
+
+		p1 = p2;
+	}
+
+	/* Return the last point on the line. This shouldn't happen, but
+	 * could if there's some floating point rounding errors. */
+	if (points_found < points_to_interpolate) {
+		getPoint4d_p(ipa, ipa->npoints - 1, &pt);
+		ptarray_set_point4d(opa, points_found, &pt);
+	}
+
+    return opa;
 }
 
