@@ -38,11 +38,12 @@
 #include "liblwgeom_internal.h"
 
 
-LWGEOM* pta_unstroke(const POINTARRAY *points, int type, int srid);
+LWGEOM* pta_unstroke(const POINTARRAY *points, int srid);
 LWGEOM* lwline_unstroke(const LWLINE *line);
 LWGEOM* lwpolygon_unstroke(const LWPOLY *poly);
 LWGEOM* lwmline_unstroke(const LWMLINE *mline);
 LWGEOM* lwmpolygon_unstroke(const LWMPOLY *mpoly);
+LWGEOM* lwcollection_unstroke(const LWCOLLECTION *c);
 LWGEOM* lwgeom_unstroke(const LWGEOM *geom);
 
 
@@ -54,7 +55,7 @@ int
 lwgeom_has_arc(const LWGEOM *geom)
 {
 	LWCOLLECTION *col;
-	int i;
+	uint32_t i;
 
 	LWDEBUG(2, "lwgeom_has_arc called.");
 
@@ -154,8 +155,13 @@ lwarc_linearize(POINTARRAY *to,
 
 	LWDEBUG(2, "lwarc_linearize called.");
 
+	LWDEBUGF(2, " curve is CIRCULARSTRING(%.15g %.15f, %.15f %.15f, %.15f %15f)",
+		t1->x, t1->y, t2->x, t2->y, t3->x, t3->y);
+
 	p2_side = lw_segment_side(t1, t3, t2);
 
+	LWDEBUGF(2, " p2 side is %d", p2_side);
+
 	/* Force counterclockwise scan if SYMMETRIC operation is requsested */
 	if ( p2_side == -1 && flags & LW_LINEARIZE_FLAG_SYMMETRIC )
 	{
@@ -206,13 +212,53 @@ lwarc_linearize(POINTARRAY *to,
 	}}
 	else if ( tolerance_type == LW_LINEARIZE_TOLERANCE_TYPE_MAX_DEVIATION )
 	{{
-		double halfAngle;
+		double halfAngle, maxErr;
 		if ( tol <= 0 )
 		{
 			lwerror("lwarc_linearize: max deviation must be bigger than 0, got %.15g", tol);
 			return -1;
 		}
-		halfAngle = acos( -tol / radius + 1 );
+
+		/*
+		 * Ref: https://en.wikipedia.org/wiki/Sagitta_(geometry)
+		 *
+		 * An arc "sagitta" (distance between middle point of arc and
+		 * middle point of corresponding chord) is defined as:
+		 *
+		 *   sagitta = radius * ( 1 - cos( angle ) );
+		 *
+		 * We want our sagitta to be at most "tolerance" long,
+		 * and we want to find out angle, so we use the inverse
+		 * formula:
+		 *
+		 *   tol = radius * ( 1 - cos( angle ) );
+		 *   1 - cos( angle ) =  tol/radius
+		 *   - cos( angle ) =  tol/radius - 1
+		 *   cos( angle ) =  - tol/radius + 1
+		 *   angle = acos( 1 - tol/radius )
+		 *
+		 * Constraints: 1.0 - tol/radius must be between -1 and 1
+		 * which means tol must be between 0 and 2 times
+		 * the radius, which makes sense as you cannot have a
+		 * sagitta bigger than twice the radius!
+		 *
+		 */
+		maxErr = tol;
+		if ( maxErr > radius * 2 )
+		{
+			maxErr = radius * 2;
+			LWDEBUGF(2, "lwarc_linearize: tolerance %g is too big, "
+			            "using arc-max 2 * radius == %g", tol, maxErr);
+		}
+		do {
+			halfAngle = acos( 1.0 - maxErr / radius );
+			/* TODO: avoid a loop here, going rather straight to
+			 *       a minimum angle value */
+			if ( halfAngle != 0 ) break;
+			LWDEBUGF(2, "lwarc_linearize: tolerance %g is too small for this arc"
+									" to compute approximation angle, doubling it", maxErr);
+			maxErr *= 2;
+		} while(1);
 		increment = 2 * halfAngle;
 		LWDEBUGF(2, "lwarc_linearize: maxDiff:%g, radius:%g, halfAngle:%g, increment:%g (%g degrees)", tol, radius, halfAngle, increment, increment*180/M_PI);
 	}}
@@ -489,7 +535,7 @@ lwcurvepoly_linearize(const LWCURVEPOLY *curvepoly, double tol,
 	LWGEOM *tmp;
 	LWLINE *line;
 	POINTARRAY **ptarray;
-	int i;
+	uint32_t i;
 
 	LWDEBUG(2, "lwcurvepoly_linearize called.");
 
@@ -549,7 +595,7 @@ lwmcurve_linearize(const LWMCURVE *mcurve, double tol,
 {
 	LWMLINE *ogeom;
 	LWGEOM **lines;
-	int i;
+	uint32_t i;
 
 	LWDEBUGF(2, "lwmcurve_linearize called, geoms=%d, dim=%d.", mcurve->ngeoms, FLAGS_NDIMS(mcurve->flags));
 
@@ -599,7 +645,7 @@ lwmsurface_linearize(const LWMSURFACE *msurface, double tol,
 	LWPOLY *poly;
 	LWGEOM **polys;
 	POINTARRAY **ptarray;
-	int i, j;
+	uint32_t i, j;
 
 	LWDEBUG(2, "lwmsurface_linearize called.");
 
@@ -643,7 +689,7 @@ lwcollection_linearize(const LWCOLLECTION *collection, double tol,
 	LWCOLLECTION *ocol;
 	LWGEOM *tmp;
 	LWGEOM **geoms;
-	int i;
+	uint32_t i;
 
 	LWDEBUG(2, "lwcollection_linearize called.");
 
@@ -669,7 +715,7 @@ lwcollection_linearize(const LWCOLLECTION *collection, double tol,
 			geoms[i] = (LWGEOM *)lwcollection_linearize((LWCOLLECTION *)tmp, tol, type, flags);
 			break;
 		default:
-			geoms[i] = lwgeom_clone(tmp);
+			geoms[i] = lwgeom_clone_deep(tmp);
 			break;
 		}
 	}
@@ -704,7 +750,7 @@ lwcurve_linearize(const LWGEOM *geom, double tol,
 		ogeom = (LWGEOM *)lwcollection_linearize((LWCOLLECTION *)geom, tol, type, flags);
 		break;
 	default:
-		ogeom = lwgeom_clone(geom);
+		ogeom = lwgeom_clone_deep(geom);
 	}
 	return ogeom;
 }
@@ -827,7 +873,7 @@ geom_from_pa(const POINTARRAY *pa, int srid, int is_arc, int start, int end)
 }
 
 LWGEOM*
-pta_unstroke(const POINTARRAY *points, int type, int srid)
+pta_unstroke(const POINTARRAY *points, int srid)
 {
 	int i = 0, j, k;
 	POINT4D a1, a2, a3, b;
@@ -923,7 +969,7 @@ pta_unstroke(const POINTARRAY *points, int type, int srid)
 
 				if ( angle < 0 ) angle = 2 * M_PI + angle;
 				num_quadrants = ( 4 * angle ) / ( 2 * M_PI );
-				LWDEBUGF(4, "arc angle (%g %g, %g %g, %g %g) is %g (side is %d), quandrants:%g", first.x, first.y, center.x, center.y, b.x, b.y, angle, p2_side, num_quadrants);
+				LWDEBUGF(4, "arc angle (%g %g, %g %g, %g %g) is %g (side is %d), quadrants:%g", first.x, first.y, center.x, center.y, b.x, b.y, angle, p2_side, num_quadrants);
 			}
 			/* a1 is first point, b is last point */
 			if ( arc_edges < min_quad_edges * num_quadrants ) {
@@ -993,22 +1039,22 @@ lwline_unstroke(const LWLINE *line)
 {
 	LWDEBUG(2, "lwline_unstroke called.");
 
-	if ( line->points->npoints < 4 ) return lwline_as_lwgeom(lwline_clone(line));
-	else return pta_unstroke(line->points, line->flags, line->srid);
+	if ( line->points->npoints < 4 ) return lwline_as_lwgeom(lwline_clone_deep(line));
+	else return pta_unstroke(line->points, line->srid);
 }
 
 LWGEOM *
 lwpolygon_unstroke(const LWPOLY *poly)
 {
 	LWGEOM **geoms;
-	int i, hascurve = 0;
+	uint32_t i, hascurve = 0;
 
 	LWDEBUG(2, "lwpolygon_unstroke called.");
 
 	geoms = lwalloc(sizeof(LWGEOM *)*poly->nrings);
 	for (i=0; i<poly->nrings; i++)
 	{
-		geoms[i] = pta_unstroke(poly->rings[i], poly->flags, poly->srid);
+		geoms[i] = pta_unstroke(poly->rings[i], poly->srid);
 		if (geoms[i]->type == CIRCSTRINGTYPE || geoms[i]->type == COMPOUNDTYPE)
 		{
 			hascurve = 1;
@@ -1020,7 +1066,7 @@ lwpolygon_unstroke(const LWPOLY *poly)
 		{
 			lwfree(geoms[i]); /* TODO: should this be lwgeom_free instead ? */
 		}
-		return lwgeom_clone((LWGEOM *)poly);
+		return lwgeom_clone_deep((LWGEOM *)poly);
 	}
 
 	return (LWGEOM *)lwcollection_construct(CURVEPOLYTYPE, poly->srid, NULL, poly->nrings, geoms);
@@ -1030,7 +1076,7 @@ LWGEOM *
 lwmline_unstroke(const LWMLINE *mline)
 {
 	LWGEOM **geoms;
-	int i, hascurve = 0;
+	uint32_t i, hascurve = 0;
 
 	LWDEBUG(2, "lwmline_unstroke called.");
 
@@ -1049,7 +1095,7 @@ lwmline_unstroke(const LWMLINE *mline)
 		{
 			lwfree(geoms[i]); /* TODO: should this be lwgeom_free instead ? */
 		}
-		return lwgeom_clone((LWGEOM *)mline);
+		return lwgeom_clone_deep((LWGEOM *)mline);
 	}
 	return (LWGEOM *)lwcollection_construct(MULTICURVETYPE, mline->srid, NULL, mline->ngeoms, geoms);
 }
@@ -1058,7 +1104,7 @@ LWGEOM *
 lwmpolygon_unstroke(const LWMPOLY *mpoly)
 {
 	LWGEOM **geoms;
-	int i, hascurve = 0;
+	uint32_t i, hascurve = 0;
 
 	LWDEBUG(2, "lwmpoly_unstroke called.");
 
@@ -1077,11 +1123,39 @@ lwmpolygon_unstroke(const LWMPOLY *mpoly)
 		{
 			lwfree(geoms[i]); /* TODO: should this be lwgeom_free instead ? */
 		}
-		return lwgeom_clone((LWGEOM *)mpoly);
+		return lwgeom_clone_deep((LWGEOM *)mpoly);
 	}
 	return (LWGEOM *)lwcollection_construct(MULTISURFACETYPE, mpoly->srid, NULL, mpoly->ngeoms, geoms);
 }
 
+LWGEOM *
+lwcollection_unstroke(const LWCOLLECTION *c)
+{
+	LWCOLLECTION *ret = lwalloc(sizeof(LWCOLLECTION));
+	memcpy(ret, c, sizeof(LWCOLLECTION));
+
+	if (c->ngeoms > 0)
+	{
+		uint32_t i;
+		ret->geoms = lwalloc(sizeof(LWGEOM *)*c->ngeoms);
+		for (i=0; i < c->ngeoms; i++)
+		{
+			ret->geoms[i] = lwgeom_unstroke(c->geoms[i]);
+		}
+		if (c->bbox)
+		{
+			ret->bbox = gbox_copy(c->bbox);
+		}
+	}
+	else
+	{
+		ret->bbox = NULL;
+		ret->geoms = NULL;
+	}
+	return (LWGEOM *)ret;
+}
+
+
 LWGEOM *
 lwgeom_unstroke(const LWGEOM *geom)
 {
@@ -1097,8 +1171,10 @@ lwgeom_unstroke(const LWGEOM *geom)
 		return lwmline_unstroke((LWMLINE *)geom);
 	case MULTIPOLYGONTYPE:
 		return lwmpolygon_unstroke((LWMPOLY *)geom);
+	case COLLECTIONTYPE:
+		return lwcollection_unstroke((LWCOLLECTION *)geom);
 	default:
-		return lwgeom_clone(geom);
+		return lwgeom_clone_deep(geom);
 	}
 }
 
