@@ -106,7 +106,7 @@ void
 lwtriangle_force_clockwise(LWTRIANGLE *triangle)
 {
 	if ( ptarray_isccw(triangle->points) )
-		ptarray_reverse(triangle->points);
+		ptarray_reverse_in_place(triangle->points);
 }
 
 int
@@ -115,13 +115,6 @@ lwtriangle_is_clockwise(LWTRIANGLE *triangle)
 	return !ptarray_isccw(triangle->points);
 }
 
-void
-lwtriangle_reverse(LWTRIANGLE *triangle)
-{
-	if( lwtriangle_is_empty(triangle) ) return;
-	ptarray_reverse(triangle->points);
-}
-
 void
 lwtriangle_release(LWTRIANGLE *lwtriangle)
 {
@@ -137,10 +130,23 @@ lwtriangle_same(const LWTRIANGLE *t1, const LWTRIANGLE *t2)
 	return r;
 }
 
+static char
+lwtriangle_is_repeated_points(LWTRIANGLE *triangle)
+{
+	char ret;
+	POINTARRAY *pa;
+
+	pa = ptarray_remove_repeated_points(triangle->points, 0.0);
+	ret = ptarray_same(pa, triangle->points);
+	ptarray_free(pa);
+
+	return ret;
+}
+
 /*
  * Construct a triangle from a LWLINE being
  * the shell
- * Pointarray from intput geom are cloned.
+ * Pointarray from input geom is cloned.
  * Input line must have 4 points, and be closed.
  */
 LWTRIANGLE *
@@ -165,19 +171,6 @@ lwtriangle_from_lwline(const LWLINE *shell)
 	return ret;
 }
 
-char
-lwtriangle_is_repeated_points(LWTRIANGLE *triangle)
-{
-	char ret;
-	POINTARRAY *pa;
-
-	pa = ptarray_remove_repeated_points(triangle->points, 0.0);
-	ret = ptarray_same(pa, triangle->points);
-	ptarray_free(pa);
-
-	return ret;
-}
-
 int lwtriangle_is_empty(const LWTRIANGLE *triangle)
 {
 	if ( !triangle->points || triangle->points->npoints < 1 )
@@ -192,7 +185,7 @@ double
 lwtriangle_area(const LWTRIANGLE *triangle)
 {
 	double area=0.0;
-	int i;
+	uint32_t i;
 	POINT2D p1;
 	POINT2D p2;
 
