@@ -66,6 +66,8 @@ GIDX* gidx_new(int ndims) ;
 /* Increase the size of a GIDX */
 void gidx_expand(GIDX *a, float d);
 
+/* Note empty GIDX */
+bool gidx_is_unknown(const GIDX *a);
 
 /* Generate human readable form for GIDX. */
 char* gidx_to_string(GIDX *a) ;
@@ -87,6 +89,27 @@ typedef float _gidx_float_array[sizeof(float) * 2 * 4];
 /* Returns the size required to store a GIDX of requested dimension */
 #define GIDX_SIZE(dimensions) (sizeof(int32) + 2*(dimensions)*sizeof(float))
 
+/* Allocate a copy of the box */
+BOX2DF* box2df_copy(BOX2DF *b);
+
+/* Grow the first argument to contain the second */
+void box2df_merge(BOX2DF *b_union, BOX2DF *b_new);
+
+/* Allocate a copy of the box */
+GIDX* gidx_copy(GIDX *b);
+
+/* Grow the first argument to contain the second */
+void gidx_merge(GIDX **b_union, GIDX *b_new);
+
+/* Note empty BOX2DF */
+bool box2df_is_empty(const BOX2DF *a);
+
+/* Fill in a gbox from a GIDX */
+void gbox_from_gidx(GIDX *a, GBOX *gbox, int flags);
+
+/* Fill in a gbox from a BOX2DF */
+int box2df_to_gbox_p(BOX2DF *a, GBOX *box);
+
 /*********************************************************************************
 ** GSERIALIZED support functions.
 **
@@ -107,7 +130,23 @@ GSERIALIZED* gserialized_set_gidx(GSERIALIZED *g, GIDX *gidx);
 GSERIALIZED* gserialized_drop_gidx(GSERIALIZED *g);
 
 bool box2df_contains(const BOX2DF *a, const BOX2DF *b);
+
+
+void box2df_set_empty(BOX2DF *a);
+void box2df_set_finite(BOX2DF *a);
+void box2df_validate(BOX2DF *b);
+bool box2df_overlaps(const BOX2DF *a, const BOX2DF *b);
+bool box2df_overleft(const BOX2DF *a, const BOX2DF *b);
+bool box2df_equals(const BOX2DF *a, const BOX2DF *b);
+bool box2df_left(const BOX2DF *a, const BOX2DF *b);
+bool box2df_right(const BOX2DF *a, const BOX2DF *b);
+bool box2df_overright(const BOX2DF *a, const BOX2DF *b);
+bool box2df_overbelow(const BOX2DF *a, const BOX2DF *b);
+bool box2df_below(const BOX2DF *a, const BOX2DF *b);
+bool box2df_above(const BOX2DF *a, const BOX2DF *b);
+bool box2df_overabove(const BOX2DF *a, const BOX2DF *b);
+
+
 bool gidx_contains(GIDX *a, GIDX *b);
 int gserialized_datum_get_box2df_p(Datum gsdatum, BOX2DF *box2df);
 
-
