@@ -124,18 +124,6 @@ GSERIALIZED* geography_serialize(LWGEOM *lwgeom);
 */
 int gserialized_datum_get_gbox_p(Datum gsdatum, GBOX *gbox);
 
-/**
-* Convert cstrings (null-terminated byte array) to textp pointers
-* (PgSQL varlena structure with VARSIZE header).
-*/
-text* cstring2text(const char *cstring);
-
-/**
-* Convert textp (PgSQL varlena structure with VARSIZE header) to
-* cstrings (null-terminated byte array).
-*/
-char* text2cstring(const text *textptr);
-
 /*
  * For PostgreSQL >= 8.5 redefine the STATRELATT macro to its
  * new value of STATRELATTINH
@@ -144,13 +132,6 @@ char* text2cstring(const text *textptr);
 	#define STATRELATT STATRELATTINH
 #endif
 
-#if POSTGIS_PGSQL_VERSION >= 110
-#ifndef FALSE
-#define FALSE 0
-#define TRUE 1
-#endif
-#endif
-
 /* PG-exposed */
 Datum BOX2D_same(PG_FUNCTION_ARGS);
 Datum BOX2D_overlap(PG_FUNCTION_ARGS);
@@ -168,7 +149,36 @@ Datum BOX2D_intersects(PG_FUNCTION_ARGS);
 Datum BOX2D_union(PG_FUNCTION_ARGS);
 
 Datum LWGEOM_same(PG_FUNCTION_ARGS);
-Datum BOX3D_construct(PG_FUNCTION_ARGS);
+
+/** needed for sp-gist support PostgreSQL 11+ **/
+//#if POSTGIS_PGSQL_VERSION > 100
+	Datum BOX3D_construct(PG_FUNCTION_ARGS);
+
+	Datum LWGEOM_to_BOX2DF(PG_FUNCTION_ARGS);
+	Datum LWGEOM_to_BOX3D(PG_FUNCTION_ARGS);
+	Datum BOX3D_contains(PG_FUNCTION_ARGS);
+	Datum BOX3D_contained(PG_FUNCTION_ARGS);
+	Datum BOX3D_overlaps(PG_FUNCTION_ARGS);
+	Datum BOX3D_same(PG_FUNCTION_ARGS);
+	Datum BOX3D_left(PG_FUNCTION_ARGS);
+	Datum BOX3D_overleft(PG_FUNCTION_ARGS);
+	Datum BOX3D_right(PG_FUNCTION_ARGS)    ;
+	Datum BOX3D_overright(PG_FUNCTION_ARGS);
+	Datum BOX3D_below(PG_FUNCTION_ARGS);
+	Datum BOX3D_overbelow(PG_FUNCTION_ARGS);
+	Datum BOX3D_above(PG_FUNCTION_ARGS);
+	Datum BOX3D_overabove(PG_FUNCTION_ARGS);
+	Datum BOX3D_front(PG_FUNCTION_ARGS);
+	Datum BOX3D_overfront(PG_FUNCTION_ARGS);
+	Datum BOX3D_back(PG_FUNCTION_ARGS);
+	Datum BOX3D_overback(PG_FUNCTION_ARGS);
+	Datum BOX3D_distance(PG_FUNCTION_ARGS);
+
+	#define DatumGetBox3DP(X)    ((BOX3D *) DatumGetPointer(X))
+	#define Box3DPGetDatum(X)    PointerGetDatum(X)
+	#define PG_GETARG_BOX3D_P(n) DatumGetBox3DP(PG_GETARG_DATUM(n))
+	#define PG_RETURN_BOX3D_P(x) return Box3DPGetDatum(x)
+//#endif
 
 Datum LWGEOM_force_2d(PG_FUNCTION_ARGS);
 Datum LWGEOM_force_3dm(PG_FUNCTION_ARGS);
