@@ -52,7 +52,7 @@ static TupleDesc get_tuple_desc(struct geobuf_agg_context *ctx)
 static void encode_keys(struct geobuf_agg_context *ctx)
 {
 	TupleDesc tupdesc = get_tuple_desc(ctx);
-	int natts = tupdesc->natts;
+	uint32_t natts = (uint32_t) tupdesc->natts;
 	char **keys = palloc(natts * sizeof(*keys));
 	uint32_t i, k = 0;
 	bool geom_found = false;
@@ -64,8 +64,7 @@ static void encode_keys(struct geobuf_agg_context *ctx)
 		Oid typoid = getBaseType(tupdesc->attrs[i].atttypid);
 		char *tkey = tupdesc->attrs[i].attname.data;
 #endif
-		char *key = palloc(strlen(tkey) + 1);
-		strcpy(key, tkey);
+		char *key = pstrdup(tkey);
 		if (ctx->geom_name == NULL) {
 			if (!geom_found && typoid == TypenameGetTypid("geometry")) {
 				ctx->geom_index = i;
@@ -106,7 +105,7 @@ static void encode_properties(struct geobuf_agg_context *ctx,
 	Data__Value **values;
 	uint32_t i, k = 0, c = 0;
 	TupleDesc tupdesc = get_tuple_desc(ctx);
-	int natts = tupdesc->natts;
+	uint32_t natts = (uint32_t) tupdesc->natts;
 	properties = palloc(sizeof (*properties) * (natts - 1) * 2);
 	values = palloc (sizeof (*values) * (natts - 1));
 
@@ -115,6 +114,7 @@ static void encode_properties(struct geobuf_agg_context *ctx,
 		char *type, *string_value;
 		Datum datum;
 		bool isnull;
+		Oid typoid;
 
 		if (i == ctx->geom_index)
 			continue;
@@ -128,9 +128,9 @@ static void encode_properties(struct geobuf_agg_context *ctx,
 		if (isnull)
 			continue;
 #if POSTGIS_PGSQL_VERSION < 110
-		Oid typoid = getBaseType(tupdesc->attrs[i]->atttypid);
+		typoid = getBaseType(tupdesc->attrs[i]->atttypid);
 #else
-		Oid typoid = getBaseType(tupdesc->attrs[i].atttypid);
+		typoid = getBaseType(tupdesc->attrs[i].atttypid);
 #endif
 		if (strcmp(type, "int2") == 0) {
 			set_int_value(value, DatumGetInt16(datum));
@@ -447,7 +447,7 @@ static void analyze_val(struct geobuf_agg_context *ctx, double val)
 
 static void analyze_pa(struct geobuf_agg_context *ctx, POINTARRAY *pa)
 {
-	int i;
+	uint32_t i;
 	POINT4D pt;
 	for (i = 0; i < pa->npoints; i++) {
 		getPoint4d_p(pa, i, &pt);
@@ -462,7 +462,7 @@ static void analyze_pa(struct geobuf_agg_context *ctx, POINTARRAY *pa)
 
 static void analyze_geometry(struct geobuf_agg_context *ctx, LWGEOM *lwgeom)
 {
-	int i, type;
+	uint32_t i, type;
 	LWLINE *lwline;
 	LWPOLY *lwpoly;
 	LWCOLLECTION *lwcollection;
@@ -564,6 +564,7 @@ void geobuf_agg_transfn(struct geobuf_agg_context *ctx)
 	bool isnull = false;
 	Datum datum;
 	Data__FeatureCollection *fc = ctx->data->feature_collection;
+/*	Data__Feature **features = fc->features; */
 	Data__Feature *feature;
 	GSERIALIZED *gs;
 	if (fc->n_features >= ctx->features_capacity) {
@@ -605,9 +606,10 @@ void geobuf_agg_transfn(struct geobuf_agg_context *ctx)
  */
 uint8_t *geobuf_agg_finalfn(struct geobuf_agg_context *ctx)
 {
-	int i;
+	size_t i, len;
 	Data *data;
 	Data__FeatureCollection *fc;
+	uint8_t *buf;
 
 	data = ctx->data;
 	fc = data->feature_collection;
@@ -630,8 +632,8 @@ uint8_t *geobuf_agg_finalfn(struct geobuf_agg_context *ctx)
 	for (i = 0; i < fc->n_features; i++)
 		fc->features[i]->geometry = encode_geometry(ctx, ctx->lwgeoms[i]);
 
-	size_t len = data__get_packed_size(data);
-	uint8_t *buf = palloc(sizeof(*buf) * (len + VARHDRSZ));
+	len = data__get_packed_size(data);
+	buf = palloc(sizeof(*buf) * (len + VARHDRSZ));
 	data__pack(data, buf + VARHDRSZ);
 
 	SET_VARSIZE(buf, VARHDRSZ + len);
