@@ -217,7 +217,7 @@ Datum geography_as_gml(PG_FUNCTION_ARGS)
 	char *srs;
 	int srid = SRID_DEFAULT;
 	int precision = DBL_DIG;
-	int option=0;
+	int option = 0;
 	int lwopts = LW_GML_IS_DIMS;
 	static const char *default_prefix = "gml:";
 	const char *prefix = default_prefix;
@@ -306,6 +306,22 @@ Datum geography_as_gml(PG_FUNCTION_ARGS)
 	/* Revert lat/lon only with long SRS */
 	if (option & 1) lwopts |= LW_GML_IS_DEGREE;
 	if (option & 2) lwopts &= ~LW_GML_IS_DIMS;
+	if (option & 8)
+	{
+		elog(ERROR,
+		     "Options %d passed to ST_AsGML(geography) sets "
+		     "unsupported value 8",
+		     option);
+		PG_RETURN_NULL();
+	}
+	if ((option & 4) || (option & 16) || (option & 32))
+	{
+		elog(ERROR,
+		     "Options %d passed to ST_AsGML(geography) but are only "
+		     "applicable to ST_AsGML(geometry)",
+		     option);
+		PG_RETURN_NULL();
+	}
 
 	if (version == 2)
 		gml = lwgeom_to_gml2(lwgeom, srs, precision, prefix);
@@ -320,7 +336,7 @@ Datum geography_as_gml(PG_FUNCTION_ARGS)
 		PG_RETURN_NULL();
 
 	/* Turn string result into text for return */
-	result = cstring2text(gml);
+	result = cstring_to_text(gml);
 	lwfree(gml);
 
 	PG_RETURN_TEXT_P(result);
@@ -399,7 +415,7 @@ Datum geography_as_kml(PG_FUNCTION_ARGS)
 	if ( ! kml )
 		PG_RETURN_NULL();
 
-	result = cstring2text(kml);
+	result = cstring_to_text(kml);
 	lwfree(kml);
 
 	PG_RETURN_TEXT_P(result);
@@ -444,7 +460,7 @@ Datum geography_as_svg(PG_FUNCTION_ARGS)
     lwgeom_free(lwgeom);
 	PG_FREE_IF_COPY(g, 0);
 
-	result = cstring2text(svg);
+	result = cstring_to_text(svg);
 	lwfree(svg);
 
 	PG_RETURN_TEXT_P(result);
@@ -521,7 +537,7 @@ Datum geography_as_geojson(PG_FUNCTION_ARGS)
 	PG_FREE_IF_COPY(g, 1);
 	if (srs) pfree(srs);
 
-	result = cstring2text(geojson);
+	result = cstring_to_text(geojson);
 	lwfree(geojson);
 
 	PG_RETURN_TEXT_P(result);
@@ -541,7 +557,7 @@ Datum geography_from_text(PG_FUNCTION_ARGS)
 	text *wkt_text = PG_GETARG_TEXT_P(0);
 
 	/* Extract the cstring from the varlena */
-	char *wkt = text2cstring(wkt_text);
+	char *wkt = text_to_cstring(wkt_text);
 
 	/* Pass the cstring to the input parser, and magic occurs! */
 	if ( lwgeom_parse_wkt(&lwg_parser_result, wkt, LW_PARSER_CHECK_ALL) == LW_FAILURE )
@@ -638,8 +654,7 @@ Datum geometry_from_geography(PG_FUNCTION_ARGS)
 
 	/* Recalculate the boxes after re-setting the geodetic bit */
 	lwgeom_set_geodetic(lwgeom, false);
-	lwgeom_drop_bbox(lwgeom);
-	lwgeom_add_bbox(lwgeom);
+	lwgeom_refresh_bbox(lwgeom);
 
 	/* We want "geometry" to think all our "geography" has an SRID, and the
 	   implied SRID is the default, so we fill that in if our SRID is actually unknown. */
