@@ -207,7 +207,6 @@ Datum geography_distance(PG_FUNCTION_ARGS)
 	GSERIALIZED* g1 = NULL;
 	GSERIALIZED* g2 = NULL;
 	double distance;
-	double tolerance = 0.0;
 	bool use_spheroid = true;
 	SPHEROID s;
 
@@ -215,10 +214,6 @@ Datum geography_distance(PG_FUNCTION_ARGS)
 	g1 = PG_GETARG_GSERIALIZED_P(0);
 	g2 = PG_GETARG_GSERIALIZED_P(1);
 
-	/* Read our tolerance value. */
-	if ( PG_NARGS() > 2 && ! PG_ARGISNULL(2) )
-		tolerance = PG_GETARG_FLOAT8(2);
-
 	/* Read our calculation type. */
 	if ( PG_NARGS() > 3 && ! PG_ARGISNULL(3) )
 		use_spheroid = PG_GETARG_BOOL(3);
@@ -243,11 +238,16 @@ Datum geography_distance(PG_FUNCTION_ARGS)
 	/* Do the brute force calculation if the cached calculation doesn't tick over */
 	if ( LW_FAILURE == geography_distance_cache(fcinfo, g1, g2, &s, &distance) )
 	{
+		/* default to using tree-based distance calculation at all times */
+		/* in standard distance call. */
+		geography_tree_distance(g1, g2, &s, FP_TOLERANCE, &distance);
+		/*
 		LWGEOM* lwgeom1 = lwgeom_from_gserialized(g1);
 		LWGEOM* lwgeom2 = lwgeom_from_gserialized(g2);
 		distance = lwgeom_distance_spheroid(lwgeom1, lwgeom2, &s, tolerance);
 		lwgeom_free(lwgeom1);
 		lwgeom_free(lwgeom2);
+		*/
 	}
 
 	/* Clean up */
@@ -309,7 +309,7 @@ Datum geography_dwithin(PG_FUNCTION_ARGS)
 	{
 		PG_FREE_IF_COPY(g1, 0);
 		PG_FREE_IF_COPY(g2, 1);
-		PG_RETURN_BOOL(FALSE);
+		PG_RETURN_BOOL(false);
 	}
 
 	/* Do the brute force calculation if the cached calculation doesn't tick over */
@@ -431,7 +431,7 @@ Datum geography_dwithin_uncached(PG_FUNCTION_ARGS)
 	/* Return FALSE on empty arguments. */
 	if ( lwgeom_is_empty(lwgeom1) || lwgeom_is_empty(lwgeom2) )
 	{
-		PG_RETURN_BOOL(FALSE);
+		PG_RETURN_BOOL(false);
 	}
 
 	distance = lwgeom_distance_spheroid(lwgeom1, lwgeom2, &s, tolerance);
@@ -446,7 +446,7 @@ Datum geography_dwithin_uncached(PG_FUNCTION_ARGS)
 	if ( distance < 0.0 )
 	{
 		elog(ERROR, "lwgeom_distance_spheroid returned negative!");
-		PG_RETURN_BOOL(FALSE);
+		PG_RETURN_BOOL(false);
 	}
 
 	PG_RETURN_BOOL(distance <= tolerance);
@@ -466,16 +466,20 @@ Datum geography_expand(PG_FUNCTION_ARGS)
 {
 	GSERIALIZED *g = NULL;
 	GSERIALIZED *g_out = NULL;
-	double distance;
+	double unit_distance, distance;
 
 	/* Get a wholly-owned pointer to the geography */
 	g = PG_GETARG_GSERIALIZED_P_COPY(0);
 
 	/* Read our distance value and normalize to unit-sphere. */
-	distance = PG_GETARG_FLOAT8(1) / WGS84_RADIUS;
+	distance = PG_GETARG_FLOAT8(1);
+	/* Magic 1% expansion is to bridge difference between potential */
+	/* spheroidal input distance and fact that expanded box filter is */
+	/* calculated on sphere */
+	unit_distance = 1.01 * distance / WGS84_RADIUS;
 
 	/* Try the expansion */
-	g_out = gserialized_expand(g, distance);
+	g_out = gserialized_expand(g, unit_distance);
 
 	/* If the expansion fails, the return our input */
 	if ( g_out == NULL )
@@ -732,16 +736,12 @@ Datum geography_covers(PG_FUNCTION_ARGS)
 	LWGEOM *lwgeom2 = NULL;
 	GSERIALIZED *g1 = NULL;
 	GSERIALIZED *g2 = NULL;
-	int type1, type2;
 	int result = LW_FALSE;
 
 	/* Get our geometry objects loaded into memory. */
 	g1 = PG_GETARG_GSERIALIZED_P(0);
 	g2 = PG_GETARG_GSERIALIZED_P(1);
 
-	type1 = gserialized_get_type(g1);
-	type2 = gserialized_get_type(g2);
-
 	/* Construct our working geometries */
 	lwgeom1 = lwgeom_from_gserialized(g1);
 	lwgeom2 = lwgeom_from_gserialized(g2);
