@@ -649,15 +649,18 @@ gserialized_datum_get_box2df_p(Datum gsdatum, BOX2DF *box2df)
 	POSTGIS_DEBUG(4, "entered function");
 
 	/*
-	** Because geometry is declared as "storage = main" anything large
-	** enough to take serious advantage of PG_DETOAST_DATUM_SLICE will have
-	** already been compressed, which means the entire object will be
-	** fetched and decompressed before a slice is taken, thus removing
-	** any efficiencies gained from slicing. We need to move to
-	** "storage = external" and implement our own geometry compressor
-	** before we can take advantage of sliced retrieval.
+	** The most info we need is the 8 bytes of serialized header plus the
+	** of floats necessary to hold the bounding box.
 	*/
-	gpart = (GSERIALIZED*)PG_DETOAST_DATUM(gsdatum);
+	if (VARATT_IS_EXTENDED(gsdatum))
+	{
+		gpart = (GSERIALIZED*)PG_DETOAST_DATUM_SLICE(gsdatum, 0, 8 + sizeof(BOX2DF));
+	}
+	else
+	{
+		gpart = (GSERIALIZED*)PG_DETOAST_DATUM(gsdatum);
+	}
+
 	flags = gpart->flags;
 
 	POSTGIS_DEBUGF(4, "got flags %d", gpart->flags);
@@ -674,21 +677,27 @@ gserialized_datum_get_box2df_p(Datum gsdatum, BOX2DF *box2df)
 	{
 		/* No, we need to calculate it from the full object. */
 		GBOX gbox;
+		GSERIALIZED *g = (GSERIALIZED*)PG_DETOAST_DATUM(gsdatum);
+
 		gbox_init(&gbox);
 
-		result = gserialized_get_gbox_p(gpart, &gbox);
-		if ( result == LW_SUCCESS )
+		if (gserialized_get_gbox_p(g, &gbox) == LW_FAILURE)
 		{
-			result = box2df_from_gbox_p(&gbox, box2df);
-		}
-		else
-		{
-			POSTGIS_DEBUG(4, "could not calculate bbox");
+			POSTGIS_DEBUG(4, "could not calculate bbox, returning failure");
+			POSTGIS_FREE_IF_COPY_P(gpart, gsdatum);
+			POSTGIS_FREE_IF_COPY_P(g, gsdatum);
+			return LW_FAILURE;
 		}
+		POSTGIS_FREE_IF_COPY_P(g, gsdatum);
+		result = box2df_from_gbox_p(&gbox, box2df);
 	}
 
 	POSTGIS_FREE_IF_COPY_P(gpart, gsdatum);
-	POSTGIS_DEBUGF(4, "result = %d, got box2df %s", result, result == LW_SUCCESS ? box2df_to_string(box2df) : "NONE");
+
+	if ( result == LW_SUCCESS )
+	{
+		POSTGIS_DEBUGF(4, "got box2df %s", box2df_to_string(box2df));
+	}
 
 	return result;
 }
