@@ -49,9 +49,33 @@ Datum pgis_geometry_polygonize_finalfn(PG_FUNCTION_ARGS);
 Datum pgis_geometry_makeline_finalfn(PG_FUNCTION_ARGS);
 Datum pgis_geometry_clusterintersecting_finalfn(PG_FUNCTION_ARGS);
 Datum pgis_geometry_clusterwithin_finalfn(PG_FUNCTION_ARGS);
+
+/** Putting pgis_abs back for ABI compatibility with 2.4 and below
+ * TODO: Drop when 3.0 rolls around **/
 Datum pgis_abs_in(PG_FUNCTION_ARGS);
 Datum pgis_abs_out(PG_FUNCTION_ARGS);
 
+/**
+** Putting back pgis_* for ABI compatibility to smooth pg_upgrade
+** TODO: Drop when 3.0 rolls around
+*/
+PG_FUNCTION_INFO_V1(pgis_abs_in);
+Datum
+pgis_abs_in(PG_FUNCTION_ARGS)
+{
+	ereport(ERROR,(errcode(ERRCODE_FEATURE_NOT_SUPPORTED),
+	               errmsg("function %s not implemented", __func__)));
+	PG_RETURN_POINTER(NULL);
+}
+PG_FUNCTION_INFO_V1(pgis_abs_out);
+Datum
+pgis_abs_out(PG_FUNCTION_ARGS)
+{
+	ereport(ERROR,(errcode(ERRCODE_FEATURE_NOT_SUPPORTED),
+	               errmsg("function %s not implemented", __func__)));
+	PG_RETURN_POINTER(NULL);
+}
+
 /* External prototypes */
 Datum pgis_union_geometry_array(PG_FUNCTION_ARGS);
 Datum LWGEOM_collect_garray(PG_FUNCTION_ARGS);
@@ -88,28 +112,6 @@ typedef struct
 pgis_abs;
 
 
-
-/**
-** We're never going to use this type externally so the in/out
-** functions are dummies.
-*/
-PG_FUNCTION_INFO_V1(pgis_abs_in);
-Datum
-pgis_abs_in(PG_FUNCTION_ARGS)
-{
-	ereport(ERROR,(errcode(ERRCODE_FEATURE_NOT_SUPPORTED),
-	               errmsg("function %s not implemented", __func__)));
-	PG_RETURN_POINTER(NULL);
-}
-PG_FUNCTION_INFO_V1(pgis_abs_out);
-Datum
-pgis_abs_out(PG_FUNCTION_ARGS)
-{
-	ereport(ERROR,(errcode(ERRCODE_FEATURE_NOT_SUPPORTED),
-	               errmsg("function %s not implemented", __func__)));
-	PG_RETURN_POINTER(NULL);
-}
-
 /**
 ** The transfer function hooks into the PostgreSQL accumArrayResult()
 ** function (present since 8.0) to build an array in a side memory
@@ -139,6 +141,7 @@ pgis_geometry_accum_transfn(PG_FUNCTION_ARGS)
 
 	if ( PG_ARGISNULL(0) )
 	{
+		MemoryContext old = MemoryContextSwitchTo(aggcontext);
 		p = (pgis_abs*) palloc(sizeof(pgis_abs));
 		p->a = NULL;
 		p->data = (Datum) NULL;
@@ -147,12 +150,11 @@ pgis_geometry_accum_transfn(PG_FUNCTION_ARGS)
 		{
 			Datum argument = PG_GETARG_DATUM(2);
 			Oid dataOid = get_fn_expr_argtype(fcinfo->flinfo, 2);
-			MemoryContext old = MemoryContextSwitchTo(aggcontext);
 
 			p->data = datumCopy(argument, get_typbyval(dataOid), get_typlen(dataOid));
 
-			MemoryContextSwitchTo(old);
 		}
+		MemoryContextSwitchTo(old);
 	}
 	else
 	{
@@ -179,7 +181,7 @@ Datum pgis_accum_finalfn(pgis_abs *p, MemoryContext mctx, FunctionCallInfo fcinf
 ** using the PostgreSQL built-in function makeMdArrayResult
 */
 Datum
-pgis_accum_finalfn(pgis_abs *p, MemoryContext mctx, FunctionCallInfo fcinfo)
+pgis_accum_finalfn(pgis_abs *p, MemoryContext mctx, __attribute__((__unused__)) FunctionCallInfo fcinfo)
 {
 	int dims[1];
 	int lbs[1];
