@@ -27,6 +27,7 @@
 
 #include "postgres.h"
 #include "fmgr.h"
+#include "access/hash.h"
 #include "utils/geo_decls.h"
 
 #include "../postgis_config.h"
@@ -55,9 +56,9 @@ Datum lwgeom_lt(PG_FUNCTION_ARGS)
 	PG_FREE_IF_COPY(g1, 0);
 	PG_FREE_IF_COPY(g2, 1);
 	if (cmp < 0)
-		PG_RETURN_BOOL(TRUE);
+		PG_RETURN_BOOL(true);
 	else
-		PG_RETURN_BOOL(FALSE);
+		PG_RETURN_BOOL(false);
 }
 
 PG_FUNCTION_INFO_V1(lwgeom_le);
@@ -69,9 +70,9 @@ Datum lwgeom_le(PG_FUNCTION_ARGS)
 	PG_FREE_IF_COPY(g1, 0);
 	PG_FREE_IF_COPY(g2, 1);
 	if (cmp == 0)
-		PG_RETURN_BOOL(TRUE);
+		PG_RETURN_BOOL(true);
 	else
-		PG_RETURN_BOOL(FALSE);
+		PG_RETURN_BOOL(false);
 }
 
 PG_FUNCTION_INFO_V1(lwgeom_eq);
@@ -83,9 +84,9 @@ Datum lwgeom_eq(PG_FUNCTION_ARGS)
 	PG_FREE_IF_COPY(g1, 0);
 	PG_FREE_IF_COPY(g2, 1);
 	if (cmp == 0)
-		PG_RETURN_BOOL(TRUE);
+		PG_RETURN_BOOL(true);
 	else
-		PG_RETURN_BOOL(FALSE);
+		PG_RETURN_BOOL(false);
 }
 
 PG_FUNCTION_INFO_V1(lwgeom_ge);
@@ -97,9 +98,9 @@ Datum lwgeom_ge(PG_FUNCTION_ARGS)
 	PG_FREE_IF_COPY(g1, 0);
 	PG_FREE_IF_COPY(g2, 1);
 	if (cmp >= 0)
-		PG_RETURN_BOOL(TRUE);
+		PG_RETURN_BOOL(true);
 	else
-		PG_RETURN_BOOL(FALSE);
+		PG_RETURN_BOOL(false);
 }
 
 PG_FUNCTION_INFO_V1(lwgeom_gt);
@@ -111,9 +112,9 @@ Datum lwgeom_gt(PG_FUNCTION_ARGS)
 	PG_FREE_IF_COPY(g1, 0);
 	PG_FREE_IF_COPY(g2, 1);
 	if (cmp > 0)
-		PG_RETURN_BOOL(TRUE);
+		PG_RETURN_BOOL(true);
 	else
-		PG_RETURN_BOOL(FALSE);
+		PG_RETURN_BOOL(false);
 }
 
 PG_FUNCTION_INFO_V1(lwgeom_cmp);
@@ -127,3 +128,31 @@ Datum lwgeom_cmp(PG_FUNCTION_ARGS)
 	PG_RETURN_INT32(ret);
 }
 
+PG_FUNCTION_INFO_V1(lwgeom_hash);
+Datum lwgeom_hash(PG_FUNCTION_ARGS)
+{
+	Datum hval;
+	GSERIALIZED *g1 = PG_GETARG_GSERIALIZED_P(0);
+	/* Point to just the type/coordinate part of buffer */
+	size_t hsz1 = gserialized_header_size(g1);
+	uint8_t *b1 = (uint8_t*)g1 + hsz1;
+	/* Calculate size of type/coordinate buffer */
+	size_t sz1 = VARSIZE(g1);
+	size_t bsz1 = sz1 - hsz1;
+	/* Calculate size of srid/type/coordinate buffer */
+	int srid = gserialized_get_srid(g1);
+	size_t bsz2 = bsz1 + sizeof(int);
+	uint8_t *b2 = palloc(bsz2);
+	/* Copy srid into front of combined buffer */
+	memcpy(b2, &srid, sizeof(int));
+	/* Copy type/coordinates into rest of combined buffer */
+	memcpy(b2+sizeof(int), b1, bsz1);
+	/* Hash combined buffer */
+	hval = hash_any(b2, bsz2);
+	pfree(b2);
+	PG_FREE_IF_COPY(g1, 0);
+	PG_RETURN_DATUM(hval);
+}
+
+
+
