@@ -48,7 +48,7 @@ Datum ST_Subdivide(PG_FUNCTION_ARGS);
 
 typedef struct GEOMDUMPNODE_T
 {
-	int idx;
+	uint32_t idx;
 	LWGEOM *geom;
 }
 GEOMDUMPNODE;
@@ -83,7 +83,7 @@ Datum LWGEOM_dump(PG_FUNCTION_ARGS)
 	Datum result;
 	char address[256];
 	char *ptr;
-	uint32 i;
+	int i;
 	char *values[2];
 
 	if (SRF_IS_FIRSTCALL())
@@ -210,7 +210,7 @@ Datum LWGEOM_dump(PG_FUNCTION_ARGS)
 
 struct POLYDUMPSTATE
 {
-	int ringnum;
+	uint32_t ringnum;
 	LWPOLY *poly;
 };
 
@@ -327,16 +327,6 @@ struct FLATCOLLECTIONDUMPSTATE
 PG_FUNCTION_INFO_V1(ST_Subdivide);
 Datum ST_Subdivide(PG_FUNCTION_ARGS)
 {
-#if POSTGIS_GEOS_VERSION < 35
-
-	elog(ERROR, "The GEOS version this PostGIS binary "
-	        "was compiled against (%d) doesn't support "
-	        "'%s' function (3.5.0+ required)",
-	        POSTGIS_GEOS_VERSION, __func__);
-	PG_RETURN_NULL();
-
-#else /* POSTGIS_GEOS_VERSION >= 35 */
-
 	typedef struct
 	{
 		int nextgeom;
@@ -412,7 +402,5 @@ Datum ST_Subdivide(PG_FUNCTION_ARGS)
 		/* do when there is no more left */
 		SRF_RETURN_DONE(funcctx);
 	}
-
-#endif /* POSTGIS_GEOS_VERSION >= 35 */
 }
 
