@@ -19,14 +19,16 @@
  **********************************************************************
  *
  * Copyright 2001-2006 Refractions Research Inc.
+ * Copyright 2017-2018 Daniel Baston <dbaston@gmail.com>
  *
  **********************************************************************/
 
 
 #include "postgres.h"
 #include "fmgr.h"
-#include "utils/elog.h"
 #include "utils/array.h"
+#include "utils/builtins.h"
+#include "utils/elog.h"
 #include "utils/geo_decls.h"
 
 #include "../postgis_config.h"
@@ -102,6 +104,7 @@ Datum LWGEOM_setpoint_linestring(PG_FUNCTION_ARGS);
 Datum LWGEOM_asEWKT(PG_FUNCTION_ARGS);
 Datum LWGEOM_hasBBOX(PG_FUNCTION_ARGS);
 Datum LWGEOM_azimuth(PG_FUNCTION_ARGS);
+Datum LWGEOM_angle(PG_FUNCTION_ARGS);
 Datum LWGEOM_affine(PG_FUNCTION_ARGS);
 Datum LWGEOM_longitude_shift(PG_FUNCTION_ARGS);
 Datum optimistic_overlap(PG_FUNCTION_ARGS);
@@ -110,8 +113,9 @@ Datum ST_MakeEnvelope(PG_FUNCTION_ARGS);
 Datum ST_CollectionExtract(PG_FUNCTION_ARGS);
 Datum ST_CollectionHomogenize(PG_FUNCTION_ARGS);
 Datum ST_IsCollection(PG_FUNCTION_ARGS);
+Datum ST_QuantizeCoordinates(PG_FUNCTION_ARGS);
 Datum ST_WrapX(PG_FUNCTION_ARGS);
-
+Datum LWGEOM_FilterByM(PG_FUNCTION_ARGS);
 
 /*------------------------------------------------------------------*/
 
@@ -139,7 +143,7 @@ Datum LWGEOM_summary(PG_FUNCTION_ARGS)
 	lwgeom_free(lwgeom);
 
 	/* create a text obj to return */
-	mytext = cstring2text(result);
+	mytext = cstring_to_text(result);
 	pfree(result);
 
 	PG_FREE_IF_COPY(geom,0);
@@ -150,7 +154,7 @@ PG_FUNCTION_INFO_V1(postgis_version);
 Datum postgis_version(PG_FUNCTION_ARGS)
 {
 	char *ver = POSTGIS_VERSION;
-	text *result = cstring2text(ver);
+	text *result = cstring_to_text(ver);
 	PG_RETURN_TEXT_P(result);
 }
 
@@ -158,7 +162,7 @@ PG_FUNCTION_INFO_V1(postgis_liblwgeom_version);
 Datum postgis_liblwgeom_version(PG_FUNCTION_ARGS)
 {
 	const char *ver = lwgeom_version();
-	text *result = cstring2text(ver);
+	text *result = cstring_to_text(ver);
 	PG_RETURN_TEXT_P(result);
 }
 
@@ -166,7 +170,7 @@ PG_FUNCTION_INFO_V1(postgis_lib_version);
 Datum postgis_lib_version(PG_FUNCTION_ARGS)
 {
 	char *ver = POSTGIS_LIB_VERSION;
-	text *result = cstring2text(ver);
+	text *result = cstring_to_text(ver);
 	PG_RETURN_TEXT_P(result);
 }
 
@@ -178,7 +182,7 @@ Datum postgis_svn_version(PG_FUNCTION_ARGS)
 	if ( rev > 0 )
 	{
 		snprintf(ver, 32, "%d", rev);
-		PG_RETURN_TEXT_P(cstring2text(ver));
+		PG_RETURN_TEXT_P(cstring_to_text(ver));
 	}
 	else
 		PG_RETURN_NULL();
@@ -188,7 +192,7 @@ PG_FUNCTION_INFO_V1(postgis_lib_build_date);
 Datum postgis_lib_build_date(PG_FUNCTION_ARGS)
 {
 	char *ver = POSTGIS_BUILD_DATE;
-	text *result = cstring2text(ver);
+	text *result = cstring_to_text(ver);
 	PG_RETURN_TEXT_P(result);
 }
 
@@ -201,23 +205,23 @@ Datum postgis_scripts_released(PG_FUNCTION_ARGS)
 	snprintf(ver, 64, "%s r%d", POSTGIS_LIB_VERSION, POSTGIS_SVN_REVISION);
 	ver[63] = '\0';
 
-	result = cstring2text(ver);
+	result = cstring_to_text(ver);
 	PG_RETURN_TEXT_P(result);
 }
 
 PG_FUNCTION_INFO_V1(postgis_uses_stats);
 Datum postgis_uses_stats(PG_FUNCTION_ARGS)
 {
-	PG_RETURN_BOOL(TRUE);
+	PG_RETURN_BOOL(true);
 }
 
 PG_FUNCTION_INFO_V1(postgis_autocache_bbox);
 Datum postgis_autocache_bbox(PG_FUNCTION_ARGS)
 {
 #ifdef POSTGIS_AUTOCACHE_BBOX
-	PG_RETURN_BOOL(TRUE);
+	PG_RETURN_BOOL(true);
 #else
-	PG_RETURN_BOOL(FALSE);
+	PG_RETURN_BOOL(false);
 #endif
 }
 
@@ -226,7 +230,7 @@ PG_FUNCTION_INFO_V1(postgis_libxml_version);
 Datum postgis_libxml_version(PG_FUNCTION_ARGS)
 {
 	char *ver = POSTGIS_LIBXML2_VERSION;
-	text *result = cstring2text(ver);
+	text *result = cstring_to_text(ver);
 	PG_RETURN_TEXT_P(result);
 }
 
@@ -1559,7 +1563,10 @@ Datum LWGEOM_makepoly(PG_FUNCTION_ARGS)
 		holes = lwalloc(sizeof(LWLINE *)*nholes);
 		for (i=0; i<nholes; i++)
 		{
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wsign-compare"
 			GSERIALIZED *g = (GSERIALIZED *)(ARR_DATA_PTR(array)+offset);
+#pragma GCC diagnostic pop
 			LWLINE *hole;
 			offset += INTALIGN(VARSIZE(g));
 			if ( gserialized_get_type(g) != LINETYPE )
@@ -1881,7 +1888,7 @@ Datum LWGEOM_reverse(PG_FUNCTION_ARGS)
 	geom = PG_GETARG_GSERIALIZED_P_COPY(0);
 
 	lwgeom = lwgeom_from_gserialized(geom);
-	lwgeom_reverse(lwgeom);
+	lwgeom_reverse_in_place(lwgeom);
 
 	geom = geometry_serialize(lwgeom);
 
@@ -2029,14 +2036,14 @@ Datum LWGEOM_same(PG_FUNCTION_ARGS)
 	{
 		PG_FREE_IF_COPY(g1, 0);
 		PG_FREE_IF_COPY(g2, 1);
-		PG_RETURN_BOOL(FALSE); /* different types */
+		PG_RETURN_BOOL(false); /* different types */
 	}
 
 	if ( gserialized_get_zm(g1) != gserialized_get_zm(g2) )
 	{
 		PG_FREE_IF_COPY(g1, 0);
 		PG_FREE_IF_COPY(g2, 1);
-		PG_RETURN_BOOL(FALSE); /* different dimensions */
+		PG_RETURN_BOOL(false); /* different dimensions */
 	}
 
 	/* ok, deserialize. */
@@ -2046,7 +2053,7 @@ Datum LWGEOM_same(PG_FUNCTION_ARGS)
 	/* invoke appropriate function */
 	result = lwgeom_same(lwg1, lwg2);
 
-	/* Relase memory */
+	/* Release memory */
 	lwgeom_free(lwg1);
 	lwgeom_free(lwg2);
 	PG_FREE_IF_COPY(g1, 0);
@@ -2159,17 +2166,13 @@ Datum LWGEOM_addpoint(PG_FUNCTION_ARGS)
 	GSERIALIZED *pglwg1, *pglwg2, *result;
 	LWPOINT *point;
 	LWLINE *line, *linecopy;
-	int where = -1;
+	int32 where = -1;
 
 	POSTGIS_DEBUGF(2, "%s called.", __func__);
 
 	pglwg1 = PG_GETARG_GSERIALIZED_P(0);
 	pglwg2 = PG_GETARG_GSERIALIZED_P(1);
 
-	if ( PG_NARGS() > 2 )
-	{
-		where = PG_GETARG_INT32(2);
-	}
 
 	if ( gserialized_get_type(pglwg1) != LINETYPE )
 	{
@@ -2185,8 +2188,16 @@ Datum LWGEOM_addpoint(PG_FUNCTION_ARGS)
 
 	line = lwgeom_as_lwline(lwgeom_from_gserialized(pglwg1));
 
-	if ( where == -1 ) where = line->points->npoints;
-	else if ( where < 0 || where > line->points->npoints )
+	if ( PG_NARGS() > 2 )
+	{
+		where = PG_GETARG_INT32(2);
+	}
+	else
+	{
+		where = line->points->npoints;
+	}
+
+	if ( where < 0 || where > (int32) line->points->npoints )
 	{
 		elog(ERROR, "Invalid offset");
 		PG_RETURN_NULL();
@@ -2196,7 +2207,7 @@ Datum LWGEOM_addpoint(PG_FUNCTION_ARGS)
 	linecopy = lwgeom_as_lwline(lwgeom_clone_deep(lwline_as_lwgeom(line)));
 	lwline_free(line);
 
-	if ( lwline_add_lwpoint(linecopy, point, where) == LW_FAILURE )
+	if ( lwline_add_lwpoint(linecopy, point, (uint32_t) where) == LW_FAILURE )
 	{
 		elog(ERROR, "Point insert failed");
 		PG_RETURN_NULL();
@@ -2298,7 +2309,7 @@ Datum LWGEOM_setpoint_linestring(PG_FUNCTION_ARGS)
 		/* Use backward indexing for negative values */
 		which = which + line->points->npoints ;
 	}
-	if ( which > line->points->npoints-1 || which < 0 )
+	if ( (uint32_t)which + 1 > line->points->npoints )
 	{
 		elog(ERROR, "abs(Point index) out of range (-)(%d..%d)", 0, line->points->npoints-1);
 		PG_RETURN_NULL();
@@ -2307,7 +2318,7 @@ Datum LWGEOM_setpoint_linestring(PG_FUNCTION_ARGS)
 	/*
 	 * This will change pointarray of the serialized pglwg1,
 	 */
-	lwline_setPoint4d(line, which, &newpoint);
+	lwline_setPoint4d(line, (uint32_t)which, &newpoint);
 	result = geometry_serialize((LWGEOM *)line);
 
 	/* Release memory */
@@ -2337,7 +2348,7 @@ Datum LWGEOM_asEWKT(PG_FUNCTION_ARGS)
 	lwgeom_free(lwgeom);
 
 	/* Write to text and free the WKT */
-	result = cstring2text(wkt);
+	result = cstring_to_text(wkt);
 	pfree(wkt);
 
 	/* Return the text */
@@ -2418,6 +2429,131 @@ Datum LWGEOM_azimuth(PG_FUNCTION_ARGS)
 	PG_RETURN_FLOAT8(result);
 }
 
+/**
+ * Compute the angle defined by 3 points or the angle between 2 vectors
+ * defined by 4 points
+ * given Point geometries.
+ * @return NULL on exception (same point).
+ * 		Return radians otherwise (always positive).
+ */
+PG_FUNCTION_INFO_V1(LWGEOM_angle);
+Datum LWGEOM_angle(PG_FUNCTION_ARGS)
+{
+	GSERIALIZED * seri_geoms[4];
+	LWGEOM *geom_unser;
+	LWPOINT *lwpoint;
+	POINT2D points[4];
+	double az1,az2 ;
+	double result;
+	int srids[4];
+	int i = 0 ;
+	int j = 0;
+	int err_code = 0;
+	int n_args = PG_NARGS();
+
+	/* no deserialize, checking for common error first*/
+	for(i=0; i<n_args; i++)
+	{
+		seri_geoms[i] = PG_GETARG_GSERIALIZED_P(i);
+		if (gserialized_is_empty(seri_geoms[i]) )
+		{/* empty geom */
+			if (i==3)
+			{
+				n_args = 3 ;
+			}
+			else
+			{
+				err_code = 1 ;
+				break ;
+			}
+		} else
+		{
+			if(gserialized_get_type(seri_geoms[i]) != POINTTYPE)
+			{/* geom type */
+				err_code = 2 ;
+				break;
+			}
+			else
+			{
+				srids[i] = gserialized_get_srid(seri_geoms[i]) ;
+				if(srids[0] != srids[i])
+				{/* error on srid*/
+					err_code = 3 ;
+					break;
+				}
+			}
+		}
+	}
+	if (err_code >0)
+		switch (err_code){
+			default: /*always executed*/
+			for (j=0;j<=i;j++)
+				PG_FREE_IF_COPY(seri_geoms[j], j);
+			/*FALLTHROUGH*/
+			case 1:
+			lwpgerror("Empty geometry");
+			PG_RETURN_NULL() ;
+			break;
+
+			case 2:
+			lwpgerror("Argument must be POINT geometries");
+			PG_RETURN_NULL();
+			break;
+
+			case 3:
+			lwpgerror("Operation on mixed SRID geometries");
+			PG_RETURN_NULL();
+			break;
+		}
+	/* extract points */
+	for(i=0; i<n_args; i++)
+	{
+		geom_unser = lwgeom_from_gserialized(seri_geoms[i]) ;
+		lwpoint = lwgeom_as_lwpoint(geom_unser);
+		if (!lwpoint)
+		{
+			for (j=0;j<n_args;j++)
+				PG_FREE_IF_COPY(seri_geoms[j], j);
+			lwpgerror("Error unserializing geometry");
+			PG_RETURN_NULL() ;
+		}
+
+		if ( ! getPoint2d_p(lwpoint->point, 0, &points[i]) )
+		{
+			/* // can't free serialized geom, it might be needed by lw
+			for (j=0;j<n_args;j++)
+				PG_FREE_IF_COPY(seri_geoms[j], j); */
+			lwpgerror("Error extracting point");
+			PG_RETURN_NULL();
+		}
+		/* lwfree(geom_unser);don't do, lw may rely on this memory
+		lwpoint_free(lwpoint); dont do , this memory is needed ! */
+	}
+	/* // can't free serialized geom, it might be needed by lw
+	for (j=0;j<n_args;j++)
+		PG_FREE_IF_COPY(seri_geoms[j], j); */
+
+	/* compute azimuth for the 2 pairs of points
+	 * note that angle is not defined identically for 3 points or 4 points*/
+	if (n_args == 3)
+	{/* we rely on azimuth to complain if points are identical */
+		if ( ! azimuth_pt_pt(&points[0], &points[1], &az1) )
+			PG_RETURN_NULL();
+		if ( ! azimuth_pt_pt(&points[2], &points[1], &az2) )
+			PG_RETURN_NULL();
+	} else
+	{
+		if ( ! azimuth_pt_pt(&points[0], &points[1], &az1) )
+			PG_RETURN_NULL();
+		if ( ! azimuth_pt_pt(&points[2], &points[3], &az2) )
+			PG_RETURN_NULL();
+	}
+	result = az2-az1 ;
+	result += (result<0) * 2 * M_PI ; /* we dont want negative angle*/
+	PG_RETURN_FLOAT8(result);
+}
+
+
 /*
  * optimistic_overlap(Polygon P1, Multipolygon MP2, double dist)
  * returns true if P1 overlaps MP2
@@ -2464,7 +2600,7 @@ Datum optimistic_overlap(PG_FUNCTION_ARGS)
 	     (g1_bvol.ymin > geom2->bbox->ymax) ||
 	     (g1_bvol.ymax < geom2->bbox->ymin) )
 	{
-		PG_RETURN_BOOL(FALSE);  /*bbox not overlap */
+		PG_RETURN_BOOL(false);  /*bbox not overlap */
 	}
 
 	/*
@@ -2506,8 +2642,7 @@ Datum LWGEOM_affine(PG_FUNCTION_ARGS)
 	/* COMPUTE_BBOX TAINTING */
 	if ( lwgeom->bbox )
 	{
-		lwgeom_drop_bbox(lwgeom);
-		lwgeom_add_bbox(lwgeom);
+		lwgeom_refresh_bbox(lwgeom);
 	}
 	ret = geometry_serialize(lwgeom);
 
@@ -2544,7 +2679,7 @@ Datum ST_GeoHash(PG_FUNCTION_ARGS)
 	if ( ! geohash )
 		PG_RETURN_NULL();
 
-	result = cstring2text(geohash);
+	result = cstring_to_text(geohash);
 	pfree(geohash);
 
 	PG_RETURN_TEXT_P(result);
@@ -2588,13 +2723,6 @@ Datum ST_CollectionExtract(PG_FUNCTION_ARGS)
 		lwcol = lwcollection_as_lwgeom(lwcollection_extract((LWCOLLECTION*)lwgeom, type));
 	}
 
-#if 0
-	if (lwgeom_is_empty(lwcollection_as_lwgeom(lwcol)))
-	{
-		lwgeom_free(lwgeom);
-		PG_RETURN_NULL();
-	}
-#endif
 	output = geometry_serialize((LWGEOM*)lwcol);
 	lwgeom_free(lwgeom);
 	lwgeom_free(lwcol);
@@ -2613,10 +2741,10 @@ Datum ST_CollectionHomogenize(PG_FUNCTION_ARGS)
 	lwoutput = lwgeom_homogenize(lwgeom);
 	lwgeom_free(lwgeom);
 
-	if ( ! lwoutput )
+	if (!lwoutput)
 	{
-		PG_RETURN_NULL();
 		PG_FREE_IF_COPY(input, 0);
+		PG_RETURN_NULL();
 	}
 
 	output = geometry_serialize(lwoutput);
@@ -2791,48 +2919,95 @@ Datum ST_Scale(PG_FUNCTION_ARGS);
 PG_FUNCTION_INFO_V1(ST_Scale);
 Datum ST_Scale(PG_FUNCTION_ARGS)
 {
-  GSERIALIZED *geom1 = PG_GETARG_GSERIALIZED_P_COPY(0); /* will be modified */
-  GSERIALIZED *geom2 = PG_GETARG_GSERIALIZED_P(1);
-  GSERIALIZED *ret;
-  LWGEOM *lwgeom1 = lwgeom_from_gserialized(geom1);
-  LWGEOM *lwgeom2 = lwgeom_from_gserialized(geom2);
-  LWPOINT *lwpoint;
-  POINT4D factors;
+	GSERIALIZED *geom;
+	GSERIALIZED *geom_scale = PG_GETARG_GSERIALIZED_P(1);
+	GSERIALIZED *geom_origin = NULL;
+	LWGEOM *lwg, *lwg_scale, *lwg_origin;
+	LWPOINT *lwpt_scale, *lwpt_origin;
+	POINT4D origin;
+	POINT4D factors;
+	bool translate = false;
+	GSERIALIZED *ret;
+	AFFINE aff;
 
-  lwpoint = lwgeom_as_lwpoint(lwgeom2);
-  if ( lwpoint == NULL )
-  {
-    lwgeom_free(lwgeom1);
-    lwgeom_free(lwgeom2);
-    PG_FREE_IF_COPY(geom1, 0);
-    PG_FREE_IF_COPY(geom2, 1);
-    lwpgerror("Scale factor geometry parameter must be a point");
-    PG_RETURN_NULL();
-  }
-  if ( ! lwpoint->point->npoints )
-  {
-    /* empty point, return input untouched */
-    lwgeom_free(lwgeom1);
-    lwgeom_free(lwgeom2);
-    PG_FREE_IF_COPY(geom2, 1);
-    PG_RETURN_POINTER(geom1);
-  }
-  getPoint4d_p(lwpoint->point, 0, &factors);
-  if ( ! FLAGS_GET_Z(lwpoint->flags ) ) factors.z = 1;
-  if ( ! FLAGS_GET_M(lwpoint->flags ) ) factors.m = 1;
+	/* Make sure we have a valid scale input */
+	lwg_scale = lwgeom_from_gserialized(geom_scale);
+	lwpt_scale = lwgeom_as_lwpoint(lwg_scale);
+	if (!lwpt_scale)
+	{
+		lwgeom_free(lwg_scale);
+		PG_FREE_IF_COPY(geom_scale, 1);
+		lwpgerror("Scale factor geometry parameter must be a point");
+		PG_RETURN_NULL();
+	}
 
-  lwgeom_scale(lwgeom1, &factors);
+	/* Geom Will be modified in place, so take a copy */
+	geom = PG_GETARG_GSERIALIZED_P_COPY(0);
+	lwg = lwgeom_from_gserialized(geom);
 
-  /* Construct GSERIALIZED */
-  ret = geometry_serialize(lwgeom1);
+	/* Empty point, return input untouched */
+	if (lwgeom_is_empty(lwg))
+	{
+		lwgeom_free(lwg_scale);
+		lwgeom_free(lwg);
+		PG_FREE_IF_COPY(geom_scale, 1);
+		PG_RETURN_POINTER(geom);
+	}
 
-  /* Cleanup */
-  lwgeom_free(lwgeom1);
-  lwgeom_free(lwgeom2);
-  PG_FREE_IF_COPY(geom1, 0);
-  PG_FREE_IF_COPY(geom2, 1);
+	/* Once we read the scale data into local static point, we can */
+	/* free the lwgeom */
+	lwpoint_getPoint4d_p(lwpt_scale, &factors);
+	if (!lwgeom_has_z(lwg_scale)) factors.z = 1.0;
+	if (!lwgeom_has_m(lwg_scale)) factors.m = 1.0;
+	lwgeom_free(lwg_scale);
 
-  PG_RETURN_POINTER(ret);
+	/* Do we have the optional false origin? */
+	if (PG_NARGS() > 2 && !PG_ARGISNULL(2))
+	{
+		geom_origin = PG_GETARG_GSERIALIZED_P(2);
+		lwg_origin = lwgeom_from_gserialized(geom_origin);
+		lwpt_origin = lwgeom_as_lwpoint(lwg_origin);
+		if (lwpt_origin)
+		{
+			lwpoint_getPoint4d_p(lwpt_origin, &origin);
+			translate = true;
+		}
+		/* Free the false origin inputs */
+		lwgeom_free(lwg_origin);
+		PG_FREE_IF_COPY(geom_origin, 2);
+	}
+
+	/* If we have false origin, translate to it before scaling */
+	if (translate)
+	{
+		/* Initialize affine */
+		memset(&aff, 0, sizeof(AFFINE));
+		/* Set rotation/scale/sheer matrix to no-op */
+		aff.afac = aff.efac = aff.ifac = 1.0;
+		/* Strip false origin from all coordinates */
+		aff.xoff = -1 * origin.x;
+		aff.yoff = -1 * origin.y;
+		aff.zoff = -1 * origin.z;
+		lwgeom_affine(lwg, &aff);
+	}
+
+	lwgeom_scale(lwg, &factors);
+
+	/* Return to original origin after scaling */
+	if (translate)
+	{
+		aff.xoff *= -1;
+		aff.yoff *= -1;
+		aff.zoff *= -1;
+		lwgeom_affine(lwg, &aff);
+	}
+
+	/* Cleanup and return */
+	ret = geometry_serialize(lwg);
+	lwgeom_free(lwg);
+	PG_FREE_IF_COPY(geom, 0);
+	PG_FREE_IF_COPY(geom_scale, 1);
+	PG_RETURN_POINTER(ret);
 }
 
 Datum ST_Points(PG_FUNCTION_ARGS);
@@ -2857,3 +3032,108 @@ Datum ST_Points(PG_FUNCTION_ARGS)
 		PG_RETURN_POINTER(ret);
 	}
 }
+
+PG_FUNCTION_INFO_V1(ST_QuantizeCoordinates);
+Datum ST_QuantizeCoordinates(PG_FUNCTION_ARGS)
+{
+	GSERIALIZED* input;
+	GSERIALIZED* result;
+	LWGEOM* g;
+	int32_t prec_x;
+	int32_t prec_y;
+	int32_t prec_z;
+	int32_t prec_m;
+
+	if (PG_ARGISNULL(0))
+		PG_RETURN_NULL();
+	if (PG_ARGISNULL(1))
+	{
+		lwpgerror("Must specify precision");
+		PG_RETURN_NULL();
+	}
+	else
+	{
+		prec_x = PG_GETARG_INT32(1);
+	}
+	prec_y = PG_ARGISNULL(2) ? prec_x : PG_GETARG_INT32(2);
+	prec_z = PG_ARGISNULL(3) ? prec_x : PG_GETARG_INT32(3);
+	prec_m = PG_ARGISNULL(4) ? prec_x : PG_GETARG_INT32(4);
+
+	input = PG_GETARG_GSERIALIZED_P_COPY(0);
+
+	g = lwgeom_from_gserialized(input);
+
+	lwgeom_trim_bits_in_place(g, prec_x, prec_y, prec_z, prec_m);
+
+	result = geometry_serialize(g);
+	lwgeom_free(g);
+	PG_FREE_IF_COPY(input, 0);
+	PG_RETURN_POINTER(result);
+}
+
+
+/*
+ * ST_FilterByM(in geometry, val double precision)
+ */
+PG_FUNCTION_INFO_V1(LWGEOM_FilterByM);
+Datum LWGEOM_FilterByM(PG_FUNCTION_ARGS)
+{
+	GSERIALIZED *geom_in;
+	GSERIALIZED *geom_out;
+	LWGEOM *lwgeom_in;
+	LWGEOM *lwgeom_out;
+	double min, max;
+	int returnm;
+	int hasm;
+
+	if ( PG_NARGS() > 0 && ! PG_ARGISNULL(0))
+	{
+		geom_in = PG_GETARG_GSERIALIZED_P(0);
+	}
+	else
+	{
+		PG_RETURN_NULL();
+	}
+
+	if ( PG_NARGS() > 1 && ! PG_ARGISNULL(1))
+		min = PG_GETARG_FLOAT8(1);
+	else
+	{
+		min = DBL_MIN;
+	}
+	if ( PG_NARGS() > 2  && ! PG_ARGISNULL(2))
+		max = PG_GETARG_FLOAT8(2);
+	else
+	{
+		max = DBL_MAX;
+	}
+	if ( PG_NARGS() > 3  && ! PG_ARGISNULL(3) && PG_GETARG_BOOL(3))
+		returnm = 1;
+	else
+	{
+		returnm=0;
+	}
+
+	if(min>max)
+	{
+		elog(ERROR,"Min-value cannot be larger than Max value\n");
+		PG_RETURN_NULL();
+	}
+
+	lwgeom_in = lwgeom_from_gserialized(geom_in);
+
+	hasm = FLAGS_GET_M(lwgeom_in->flags);
+
+	if(!hasm)
+	{
+		elog(NOTICE,"No M-value, No vertex removed\n");
+		PG_RETURN_POINTER(geom_in);
+	}
+
+	lwgeom_out = lwgeom_filter_m(lwgeom_in, min, max,returnm);
+
+	geom_out = geometry_serialize(lwgeom_out);
+	lwgeom_free(lwgeom_out);
+	PG_RETURN_POINTER(geom_out);
+
+}
