@@ -38,6 +38,28 @@
 # else
 #  include <json/json.h>
 # endif
+
+/* We don't include <utils/builtins.h> to avoid collisions with json-c/json.h */
+static text*
+cstring2text(const char *cstring)
+{
+	size_t len = strlen(cstring);
+	text *result = (text *) palloc(len + VARHDRSZ);
+	SET_VARSIZE(result, len + VARHDRSZ);
+	memcpy(VARDATA(result), cstring, len);
+
+	return result;
+}
+
+static char*
+text2cstring(const text *textptr)
+{
+	size_t size = VARSIZE(textptr) - VARHDRSZ;
+	char *str = lwalloc(size+1);
+	memcpy(str, VARDATA(textptr), size);
+	str[size]='\0';
+	return str;
+}
 #endif
 
 Datum geom_from_geojson(PG_FUNCTION_ARGS);
