@@ -54,6 +54,7 @@
 
 #include "postgres.h"
 #include "executor/spi.h"
+#include "utils/builtins.h"
 
 #include "../postgis_config.h"
 #include "lwgeom_pg.h"
@@ -78,7 +79,7 @@ gmlSrs;
 
 
 
-static void gml_lwpgerror(char *msg, int error_code)
+static void gml_lwpgerror(char *msg, __attribute__((__unused__)) int error_code)
 {
         POSTGIS_DEBUGF(3, "ST_GeomFromGML ERROR %i", error_code);
         lwpgerror("%s", msg);
@@ -106,7 +107,7 @@ Datum geom_from_gml(PG_FUNCTION_ARGS)
 	/* Get the GML stream */
 	if (PG_ARGISNULL(0)) PG_RETURN_NULL();
 	xml_input = PG_GETARG_TEXT_P(0);
-	xml = text2cstring(xml_input);
+	xml = text_to_cstring(xml_input);
 
 	/* Zero for undefined */
 	root_srid = PG_GETARG_INT32(1);
@@ -168,7 +169,7 @@ static bool is_gml_namespace(xmlNodePtr xnode, bool is_strict)
 
 
 /**
- * Retrieve a GML propertie from a node or NULL otherwise
+ * Retrieve a GML property from a node or NULL otherwise
  * Respect namespaces if presents in the node element
  */
 static xmlChar *gmlGetProp(xmlNodePtr xnode, xmlChar *prop)
@@ -681,7 +682,6 @@ static POINTARRAY* parse_gml_coord(xmlNodePtr xnode, bool *hasz)
 	if (!z) *hasz = false;
 
 	ptarray_append_point(dpa, &p, LW_FALSE);
-	x = y = z = false;
 
 	return dpa; /* ptarray_clone_deep(dpa); */
 }
@@ -1027,7 +1027,7 @@ static LWGEOM* parse_gml_curve(xmlNodePtr xnode, bool *hasz, int *root_srid)
 		if (!is_gml_namespace(xa, false)) continue;
 		if (strcmp((char *) xa->name, "LineStringSegment")) continue;
 
-		/* GML SF is resticted to linear interpolation  */
+		/* GML SF is restricted to linear interpolation  */
 		interpolation = gmlGetProp(xa, (xmlChar *) "interpolation");
 		if (interpolation != NULL)
 		{
@@ -1056,7 +1056,7 @@ static LWGEOM* parse_gml_curve(xmlNodePtr xnode, bool *hasz, int *root_srid)
 	 *  segment"  from  ISO 19107:2003 -> 6.3.16.1 (p43)
 	 *
 	 * So we must aggregate all the segments into a single one and avoid
-	 * to copy the redundants points
+	 * to copy the redundant points
 	 */
 	if (lss > 1)
 	{
@@ -1231,7 +1231,7 @@ static LWGEOM* parse_gml_triangle(xmlNodePtr xnode, bool *hasz, int *root_srid)
 	if (xnode->children == NULL)
 		return lwtriangle_as_lwgeom(lwtriangle_construct_empty(*root_srid, 0, 0));
 
-	/* GML SF is resticted to planar interpolation
+	/* GML SF is restricted to planar interpolation
 	       NOTA: I know Triangle is not part of SF, but
 	       we have to be consistent with other surfaces */
 	interpolation = gmlGetProp(xnode, (xmlChar *) "interpolation");
@@ -1298,7 +1298,7 @@ static LWGEOM* parse_gml_patch(xmlNodePtr xnode, bool *hasz, int *root_srid)
 	if (strcmp((char *) xnode->name, "PolygonPatch"))
 		gml_lwpgerror("invalid GML representation", 48);
 
-	/* GML SF is resticted to planar interpolation  */
+	/* GML SF is restricted to planar interpolation  */
 	interpolation = gmlGetProp(xnode, (xmlChar *) "interpolation");
 	if (interpolation != NULL)
 	{
@@ -1514,9 +1514,9 @@ static LWGEOM* parse_gml_mpoint(xmlNodePtr xnode, bool *hasz, int *root_srid)
 		{
 			for (xb = xa->children ; xb != NULL ; xb = xb->next)
 			{
-				if (xb != NULL)
-					geom = (LWGEOM*)lwmpoint_add_lwpoint((LWMPOINT*)geom,
-				                                         (LWPOINT*)parse_gml(xb, hasz, root_srid));
+				geom = (LWGEOM*)lwmpoint_add_lwpoint(
+				    (LWMPOINT*)geom,
+				    (LWPOINT*)parse_gml(xb, hasz, root_srid));
 			}
 		}
 		else if (!strcmp((char *) xa->name, "pointMember"))
