@@ -25,6 +25,7 @@
 
 #include "postgres.h"
 #include "fmgr.h"
+#include "utils/builtins.h"
 
 #include "../postgis_config.h"
 #include "liblwgeom.h"
@@ -55,30 +56,28 @@ Datum transform(PG_FUNCTION_ARGS)
 	output_srid = PG_GETARG_INT32(1);
 	if (output_srid == SRID_UNKNOWN)
 	{
-		elog(ERROR,"%d is an invalid target SRID",SRID_UNKNOWN);
+		elog(ERROR, "%d is an invalid target SRID", SRID_UNKNOWN);
 		PG_RETURN_NULL();
 	}
 
 	geom = PG_GETARG_GSERIALIZED_P_COPY(0);
 	input_srid = gserialized_get_srid(geom);
+
 	if ( input_srid == SRID_UNKNOWN )
 	{
 		PG_FREE_IF_COPY(geom, 0);
-		elog(ERROR,"Input geometry has unknown (%d) SRID",SRID_UNKNOWN);
+		elog(ERROR, "Input geometry has unknown (%d) SRID", SRID_UNKNOWN);
 		PG_RETURN_NULL();
 	}
 
-	/*
-	 * If input SRID and output SRID are equal, return geometry
-	 * without transform it
-	 */
+	/* Input SRID and output SRID are equal, noop */
 	if ( input_srid == output_srid )
-		PG_RETURN_POINTER(PG_GETARG_DATUM(0));
+		PG_RETURN_POINTER(geom);
 
 	if ( GetProjectionsUsingFCInfo(fcinfo, input_srid, output_srid, &input_pj, &output_pj) == LW_FAILURE )
 	{
 		PG_FREE_IF_COPY(geom, 0);
-		elog(ERROR,"Failure reading projections from spatial_ref_sys.");
+		elog(ERROR, "Failure reading projections from spatial_ref_sys.");
 		PG_RETURN_NULL();
 	}
 
@@ -90,8 +89,7 @@ Datum transform(PG_FUNCTION_ARGS)
 	/* Re-compute bbox if input had one (COMPUTE_BBOX TAINTING) */
 	if ( lwgeom->bbox )
 	{
-		lwgeom_drop_bbox(lwgeom);
-		lwgeom_add_bbox(lwgeom);
+		lwgeom_refresh_bbox(lwgeom);
 	}
 
 	result = geometry_serialize(lwgeom);
@@ -133,8 +131,8 @@ Datum transform_geom(PG_FUNCTION_ARGS)
 	output_proj4_text = (PG_GETARG_TEXT_P(2));
 
 	/* Convert from text to cstring for libproj */
-	input_proj4 = text2cstring(input_proj4_text);
-	output_proj4 = text2cstring(output_proj4_text);
+	input_proj4 = text_to_cstring(input_proj4_text);
+	output_proj4 = text_to_cstring(output_proj4_text);
 
 	/* make input and output projection objects */
 	input_pj = lwproj_from_string(input_proj4);
@@ -186,8 +184,7 @@ Datum transform_geom(PG_FUNCTION_ARGS)
 	/* Re-compute bbox if input had one (COMPUTE_BBOX TAINTING) */
 	if ( lwgeom->bbox )
 	{
-		lwgeom_drop_bbox(lwgeom);
-		lwgeom_add_bbox(lwgeom);
+		lwgeom_refresh_bbox(lwgeom);
 	}
 
 	result = geometry_serialize(lwgeom);
@@ -203,6 +200,6 @@ PG_FUNCTION_INFO_V1(postgis_proj_version);
 Datum postgis_proj_version(PG_FUNCTION_ARGS)
 {
 	const char *ver = pj_get_release();
-	text *result = cstring2text(ver);
+	text *result = cstring_to_text(ver);
 	PG_RETURN_POINTER(result);
 }
