@@ -727,6 +727,39 @@ static void parse_values(mvt_agg_context *ctx)
 	POSTGIS_DEBUGF(3, "parse_values n_tags %zd", ctx->feature->n_tags);
 }
 
+/* For a given geometry, look for the highest dimensional basic type, that is,
+ * point, line or polygon */
+static uint8
+lwgeom_get_basic_type(LWGEOM *geom)
+{
+	switch(geom->type)
+	{
+	case POINTTYPE:
+	case LINETYPE:
+	case POLYGONTYPE:
+		return geom->type;
+	case MULTIPOINTTYPE:
+	case MULTILINETYPE:
+	case MULTIPOLYGONTYPE:
+		return geom->type - 3; /* Based on LWTYPE positions */
+	case COLLECTIONTYPE:
+	{
+		uint32_t i;
+		uint8 type = 0;
+		LWCOLLECTION *g = (LWCOLLECTION*)geom;
+		for (i = 0; i < g->ngeoms; i++)
+		{
+			LWGEOM *sg = g->geoms[i];
+			type = Max(type, lwgeom_get_basic_type(sg));
+		}
+		return type;
+	}
+	default:
+		elog(ERROR, "%s: Invalid type (%d)", __func__, geom->type);
+	}
+}
+
+
 /**
  * In place process a collection to find a concrete geometry
  * object and expose that as the actual object. Will some
@@ -734,27 +767,12 @@ static void parse_values(mvt_agg_context *ctx)
  * draw it anyways.
  */
 static void
-lwgeom_to_basic_type(LWGEOM *geom)
+lwgeom_to_basic_type(LWGEOM *geom, uint8 original_type)
 {
 	if (lwgeom_get_type(geom) == COLLECTIONTYPE)
 	{
-		/* MVT doesn't handle generic collections, so we */
-		/* need to strip them down to a typed collection */
-		/* by finding the largest basic type available and */
-		/* using that as the basis of a typed collection. */
 		LWCOLLECTION *g = (LWCOLLECTION*)geom;
-		LWCOLLECTION *gc;
-		uint32_t i, maxtype = 0;
-		for (i = 0; i < g->ngeoms; i++)
-		{
-			LWGEOM *sg = g->geoms[i];
-			if (sg->type > maxtype && sg->type < COLLECTIONTYPE)
-				maxtype = sg->type;
-		}
-		if (maxtype > 3) maxtype -= 3;
-		/* Force the working geometry to be a simpler version */
-		/* of itself */
-		gc = lwcollection_extract(g, maxtype);
+		LWCOLLECTION *gc = lwcollection_extract(g, original_type);
 		*g = *gc;
 	}
 }
@@ -776,6 +794,7 @@ LWGEOM *mvt_geom(LWGEOM *lwgeom, const GBOX *gbox, uint32_t extent, uint32_t buf
 	double height = gbox->ymax - gbox->ymin;
 	double resx, resy, res, fx, fy;
 	int preserve_collapsed = LW_TRUE;
+	const uint8_t basic_type = lwgeom_get_basic_type(lwgeom);
 	POSTGIS_DEBUG(2, "mvt_geom called");
 
 	/* Short circuit out on EMPTY */
@@ -822,10 +841,28 @@ LWGEOM *mvt_geom(LWGEOM *lwgeom, const GBOX *gbox, uint32_t extent, uint32_t buf
 			double y0 = bgbox.ymin;
 			double x1 = bgbox.xmax;
 			double y1 = bgbox.ymax;
-			lwgeom = lwgeom_clip_by_rect(lwgeom, x0, y0, x1, y1);
-			POSTGIS_DEBUG(3, "mvt_geom: no geometry after clip");
-			if (lwgeom == NULL || lwgeom_is_empty(lwgeom))
+			const GBOX pre_clip_box = *lwgeom_get_bbox(lwgeom);
+			LWGEOM *clipped_geom = lwgeom_clip_by_rect(lwgeom, x0, y0, x1, y1);
+			if (clipped_geom == NULL || lwgeom_is_empty(clipped_geom))
+			{
+				POSTGIS_DEBUG(3, "mvt_geom: no geometry after clip");
 				return NULL;
+			}
+			/* For some polygons, the simplify step might have left them
+			 * as invalid, which can cause clipping to return the complementary
+			 * geometry of what it should */
+			if ((basic_type == POLYGONTYPE) &&
+			    !gbox_contains_2d(&pre_clip_box, lwgeom_get_bbox(clipped_geom)))
+			{
+				/* TODO: Adapt this when and if Exception Policies are introduced.
+				 * Other options would be to fix the geometry and retry
+				 * or to calculate the difference between the 2 boxes.
+				 */
+				POSTGIS_DEBUG(3, "mvt_geom: Invalid geometry after clipping");
+				lwgeom_free(clipped_geom);
+				return NULL;
+			}
+			lwgeom = clipped_geom;
 		}
 	}
 
@@ -850,22 +887,11 @@ LWGEOM *mvt_geom(LWGEOM *lwgeom, const GBOX *gbox, uint32_t extent, uint32_t buf
 		return NULL;
 
 
-	if (lwgeom->type == POLYGONTYPE ||
-		lwgeom->type == MULTIPOLYGONTYPE ||
-		lwgeom->type == COLLECTIONTYPE)
+	if (basic_type == POLYGONTYPE)
 	{
 		/* Force validation as per MVT spec */
 		lwgeom = lwgeom_make_valid(lwgeom);
 
-		/* Drop type changes tp play nice with MVT renderers */
-		if (!(lwgeom->type == POLYGONTYPE ||
-			lwgeom->type == MULTIPOLYGONTYPE ||
-			lwgeom->type == COLLECTIONTYPE))
-		{
-			lwgeom_free(lwgeom);
-			return NULL;
-		}
-
 		/* In image coordinates CW actually comes out a CCW, so we reverse */
 		lwgeom_force_clockwise(lwgeom);
 		lwgeom_reverse_in_place(lwgeom);
@@ -873,7 +899,14 @@ LWGEOM *mvt_geom(LWGEOM *lwgeom, const GBOX *gbox, uint32_t extent, uint32_t buf
 
 	/* if geometry collection extract highest dimensional geometry type */
 	if (lwgeom->type == COLLECTIONTYPE)
-		lwgeom_to_basic_type(lwgeom);
+		lwgeom_to_basic_type(lwgeom, basic_type);
+
+	if (basic_type != lwgeom_get_basic_type(lwgeom))
+	{
+		/* Drop type changes to play nice with MVT renderers */
+		POSTGIS_DEBUG(3, "mvt_geom: Dropping geometry after type change");
+		return NULL;
+	}
 
 	if (lwgeom == NULL || lwgeom_is_empty(lwgeom))
 		return NULL;
