@@ -14,7 +14,7 @@ Datum postgis_libprotobuf_version(PG_FUNCTION_ARGS)
 	PG_RETURN_NULL();
 #else /* HAVE_LIBPROTOBUF  */
 	const char *ver = protobuf_c_version();
-	text *result = cstring2text(ver);
+	text *result = cstring_to_text(ver);
 	PG_RETURN_POINTER(result);
 #endif
 }
\ No newline at end of file
