@@ -188,6 +188,8 @@ Datum RASTER_convex_hull(PG_FUNCTION_ARGS)
 	PG_RETURN_POINTER(gser);
 }
 
+#define VALUES_LENGTH 2
+
 PG_FUNCTION_INFO_V1(RASTER_dumpAsPolygons);
 Datum RASTER_dumpAsPolygons(PG_FUNCTION_ARGS) {
 	FuncCallContext *funcctx;
@@ -309,9 +311,8 @@ Datum RASTER_dumpAsPolygons(PG_FUNCTION_ARGS) {
 
 	/* do when there is more left to send */
 	if (call_cntr < max_calls) {
-		int values_length = 2;
-		Datum values[values_length];
-		bool nulls[values_length];
+		Datum values[VALUES_LENGTH];
+		bool nulls[VALUES_LENGTH];
 		HeapTuple    tuple;
 		Datum        result;
 
@@ -320,7 +321,7 @@ Datum RASTER_dumpAsPolygons(PG_FUNCTION_ARGS) {
 
 		POSTGIS_RT_DEBUGF(3, "call number %d", call_cntr);
 
-		memset(nulls, FALSE, sizeof(bool) * values_length);
+		memset(nulls, FALSE, sizeof(bool) * VALUES_LENGTH);
 
 		/* convert LWGEOM to GSERIALIZED */
 		gser = gserialized_from_lwgeom(lwpoly_as_lwgeom(geomval2[call_cntr].geom), &gser_size);
@@ -344,6 +345,9 @@ Datum RASTER_dumpAsPolygons(PG_FUNCTION_ARGS) {
 	}
 }
 
+#undef VALUES_LENGTH
+#define VALUES_LENGTH 4
+
 /**
  * Return the geographical shape of all pixels
  */
@@ -611,9 +615,8 @@ Datum RASTER_getPixelPolygons(PG_FUNCTION_ARGS)
 
 	/* do when there is more left to send */
 	if (call_cntr < max_calls) {
-		int values_length = 4;
-		Datum values[values_length];
-		bool nulls[values_length];
+		Datum values[VALUES_LENGTH];
+		bool nulls[VALUES_LENGTH];
 		HeapTuple tuple;
 		Datum result;
 
@@ -622,7 +625,7 @@ Datum RASTER_getPixelPolygons(PG_FUNCTION_ARGS)
 
 		POSTGIS_RT_DEBUGF(3, "call number %d", call_cntr);
 
-		memset(nulls, FALSE, sizeof(bool) * values_length);
+		memset(nulls, FALSE, sizeof(bool) * VALUES_LENGTH);
 
 		/* convert LWGEOM to GSERIALIZED */
 		gser = gserialized_from_lwgeom(pix2[call_cntr].geom, &gser_size);
@@ -756,14 +759,14 @@ Datum RASTER_asRaster(PG_FUNCTION_ARGS)
 	char *pixeltype = NULL;
 	rt_pixtype pixtype = PT_END;
 	rt_pixtype *pixtypes = NULL;
-	int pixtypes_len = 0;
+	uint32_t pixtypes_len = 0;
 
 	double *values = NULL;
-	int values_len = 0;
+	uint32_t values_len = 0;
 
 	uint8_t *hasnodatas = NULL;
 	double *nodatavals = NULL;
-	int nodatavals_len = 0;
+	uint32_t nodatavals_len = 0;
 
 	double ulw[2] = {0};
 	double *ul_xw = NULL;
@@ -1199,7 +1202,7 @@ Datum RASTER_asRaster(PG_FUNCTION_ARGS)
 
 	/* all touched */
 	if (!PG_ARGISNULL(14) && PG_GETARG_BOOL(14) == TRUE) {
-		if (options_len < 1) {
+		if (options_len == 0) {
 			options_len = 1;
 			options = (char **) palloc(sizeof(char *) * options_len);
 		}
@@ -1209,7 +1212,7 @@ Datum RASTER_asRaster(PG_FUNCTION_ARGS)
 		}
 
 		options[options_len - 1] = palloc(sizeof(char*) * (strlen("ALL_TOUCHED=TRUE") + 1));
-		options[options_len - 1] = "ALL_TOUCHED=TRUE";
+		strcpy(options[options_len - 1], "ALL_TOUCHED=TRUE");
 	}
 
 	if (options_len) {
