@@ -3,7 +3,6 @@ set client_min_messages to ERROR;
 
 INSERT INTO spatial_ref_sys ( auth_name, auth_srid, srid, proj4text ) VALUES ( 'EPSG', 4326, 4326, '+proj=longlat +ellps=WGS84 +datum=WGS84 +no_defs' );
 
-
 -- Import city_data
 \i load_topology-4326.sql
 
@@ -136,6 +135,20 @@ BEGIN
 END
 $$ language 'plpgsql';
 
+-- Runs a query and returns whether an error was thrown
+-- Useful when the error message depends on the execution plan taken (parallelism)
+CREATE OR REPLACE FUNCTION catch_error(query text)
+RETURNS bool
+AS $$
+BEGIN
+    EXECUTE query;
+    RETURN FALSE;
+EXCEPTION
+    WHEN OTHERS THEN
+        RETURN TRUE;
+END
+$$ LANGUAGE 'plpgsql';
+
 -- }
 
 -- Save current state
@@ -152,7 +165,6 @@ SELECT * FROM check_edges('bogus');
 SELECT * FROM check_faces('bogus');
 -- }
 
-
 -- Remove isolated edge
 SELECT 'RM(25)', topology.ST_RemEdgeModFace('city_data', 25);
 SELECT * FROM check_nodes('RM(25)/nodes');
@@ -214,7 +226,6 @@ SELECT * FROM check_edges('RM(15)/edges');
 SELECT * FROM check_faces('RM(15)/faces');
 SELECT save_edges(); SELECT save_faces(); SELECT save_nodes();
 
-
 -- Universe flooding existing single-edge (closed) face
 -- with dangling edge starting from the closing node and
 -- going inside.
@@ -360,7 +371,6 @@ SELECT save_edges(); SELECT save_faces(); SELECT save_nodes();
 
 SELECT topology.DropTopology('city_data');
 
-
 -------------------------------------------------------------------------
 -- Now test in presence of features
 -------------------------------------------------------------------------
@@ -380,7 +390,7 @@ SELECT '*RM(5)', topology.ST_RemEdgeModFace('city_data', 5);
 -- Two land_parcels (P2 and P3) are defined by either face
 -- 5 but not face 4 or by face 4 but not face 5, so we can't heal
 -- the faces by dropping edge 17
-SELECT '*RM(17)', topology.ST_RemEdgeModFace('city_data', 17);
+SELECT '*RM(17)', catch_error($$SELECT topology.ST_RemEdgeModFace('city_data', 17)$$);
 
 -- Dropping edge 11 is fine as it heals faces 5 and 8, which
 -- only serve definition of land_parcel P3 which contains both
@@ -413,6 +423,6 @@ DROP FUNCTION save_faces();
 DROP FUNCTION check_faces(text);
 DROP FUNCTION save_nodes();
 DROP FUNCTION check_nodes(text);
+DROP FUNCTION catch_error(text);
 DELETE FROM spatial_ref_sys where srid = 4326;
 
-
